/* UnicodeCategories.h */
/* THIS IS A GENERATED FILE. CHANGES WILL BE OVERWRITTEN. */
/* Generated by generate-unicode-tables.pl */
/* Generated from UCD version 5.0 */

#pragma once

#include <QtGlobal>

enum EUnicodeCategory {
    UNICODE_UPPERCASE_LETTER,
    UNICODE_LOWERCASE_LETTER,
    UNICODE_TITLECASE_LETTER,
    UNICODE_NON_SPACING_MARK,
    UNICODE_COMBINING_MARK,
    UNICODE_ENCLOSING_MARK,
    UNICODE_DECIMAL_NUMBER,
    UNICODE_LETTER_NUMBER,
    UNICODE_OTHER_NUMBER,
    UNICODE_SPACE_SEPARATOR,
    UNICODE_LINE_SEPARATOR,
    UNICODE_PARAGRAPH_SEPARATOR,
    UNICODE_CONTROL,
    UNICODE_FORMAT,
    UNICODE_SURROGATE,
    UNICODE_PRIVATE_USE,
    UNICODE_UNASSIGNED,
    UNICODE_MODIFIER_LETTER,
    UNICODE_OTHER_LETTER,
    UNICODE_CONNECT_PUNCTUATION,
    UNICODE_DASH_PUNCTUATION,
    UNICODE_OPEN_PUNCTUATION,
    UNICODE_CLOSE_PUNCTUATION,
    UNICODE_INITIAL_PUNCTUATION,
    UNICODE_FINAL_PUNCTUATION,
    UNICODE_OTHER_PUNCTUATION,
    UNICODE_MATH_SYMBOL,
    UNICODE_CURRENCY_SYMBOL,
    UNICODE_MODIFIER_SYMBOL,
    UNICODE_OTHER_SYMBOL,

    UNICODE_INVALID,
};

struct TUnicodeCategory {
    quint32 start;
    quint32 end;
    EUnicodeCategory category;
};

static const TUnicodeCategory constUnicodeCategoryList[] = {{0x0000, 0x001F, UNICODE_CONTROL},
                                                            {0x0020, 0x0020, UNICODE_SPACE_SEPARATOR},
                                                            {0x0021, 0x0023, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0024, 0x0024, UNICODE_CURRENCY_SYMBOL},
                                                            {0x0025, 0x0027, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0028, 0x0028, UNICODE_OPEN_PUNCTUATION},
                                                            {0x0029, 0x0029, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x002A, 0x002A, UNICODE_OTHER_PUNCTUATION},
                                                            {0x002B, 0x002B, UNICODE_MATH_SYMBOL},
                                                            {0x002C, 0x002C, UNICODE_OTHER_PUNCTUATION},
                                                            {0x002D, 0x002D, UNICODE_DASH_PUNCTUATION},
                                                            {0x002E, 0x002F, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0030, 0x0039, UNICODE_DECIMAL_NUMBER},
                                                            {0x003A, 0x003B, UNICODE_OTHER_PUNCTUATION},
                                                            {0x003C, 0x003E, UNICODE_MATH_SYMBOL},
                                                            {0x003F, 0x0040, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0041, 0x005A, UNICODE_UPPERCASE_LETTER},
                                                            {0x005B, 0x005B, UNICODE_OPEN_PUNCTUATION},
                                                            {0x005C, 0x005C, UNICODE_OTHER_PUNCTUATION},
                                                            {0x005D, 0x005D, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x005E, 0x005E, UNICODE_MODIFIER_SYMBOL},
                                                            {0x005F, 0x005F, UNICODE_CONNECT_PUNCTUATION},
                                                            {0x0060, 0x0060, UNICODE_MODIFIER_SYMBOL},
                                                            {0x0061, 0x007A, UNICODE_LOWERCASE_LETTER},
                                                            {0x007B, 0x007B, UNICODE_OPEN_PUNCTUATION},
                                                            {0x007C, 0x007C, UNICODE_MATH_SYMBOL},
                                                            {0x007D, 0x007D, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x007E, 0x007E, UNICODE_MATH_SYMBOL},
                                                            {0x007F, 0x009F, UNICODE_CONTROL},
                                                            {0x00A0, 0x00A0, UNICODE_SPACE_SEPARATOR},
                                                            {0x00A1, 0x00A1, UNICODE_OTHER_PUNCTUATION},
                                                            {0x00A2, 0x00A5, UNICODE_CURRENCY_SYMBOL},
                                                            {0x00A6, 0x00A7, UNICODE_OTHER_SYMBOL},
                                                            {0x00A8, 0x00A8, UNICODE_MODIFIER_SYMBOL},
                                                            {0x00A9, 0x00A9, UNICODE_OTHER_SYMBOL},
                                                            {0x00AA, 0x00AA, UNICODE_LOWERCASE_LETTER},
                                                            {0x00AB, 0x00AB, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x00AC, 0x00AC, UNICODE_MATH_SYMBOL},
                                                            {0x00AD, 0x00AD, UNICODE_FORMAT},
                                                            {0x00AE, 0x00AE, UNICODE_OTHER_SYMBOL},
                                                            {0x00AF, 0x00AF, UNICODE_MODIFIER_SYMBOL},
                                                            {0x00B0, 0x00B0, UNICODE_OTHER_SYMBOL},
                                                            {0x00B1, 0x00B1, UNICODE_MATH_SYMBOL},
                                                            {0x00B2, 0x00B3, UNICODE_OTHER_NUMBER},
                                                            {0x00B4, 0x00B4, UNICODE_MODIFIER_SYMBOL},
                                                            {0x00B5, 0x00B5, UNICODE_LOWERCASE_LETTER},
                                                            {0x00B6, 0x00B6, UNICODE_OTHER_SYMBOL},
                                                            {0x00B7, 0x00B7, UNICODE_OTHER_PUNCTUATION},
                                                            {0x00B8, 0x00B8, UNICODE_MODIFIER_SYMBOL},
                                                            {0x00B9, 0x00B9, UNICODE_OTHER_NUMBER},
                                                            {0x00BA, 0x00BA, UNICODE_LOWERCASE_LETTER},
                                                            {0x00BB, 0x00BB, UNICODE_FINAL_PUNCTUATION},
                                                            {0x00BC, 0x00BE, UNICODE_OTHER_NUMBER},
                                                            {0x00BF, 0x00BF, UNICODE_OTHER_PUNCTUATION},
                                                            {0x00C0, 0x00D6, UNICODE_UPPERCASE_LETTER},
                                                            {0x00D7, 0x00D7, UNICODE_MATH_SYMBOL},
                                                            {0x00D8, 0x00DE, UNICODE_UPPERCASE_LETTER},
                                                            {0x00DF, 0x00F6, UNICODE_LOWERCASE_LETTER},
                                                            {0x00F7, 0x00F7, UNICODE_MATH_SYMBOL},
                                                            {0x00F8, 0x00FF, UNICODE_LOWERCASE_LETTER},
                                                            {0x0100, 0x0100, UNICODE_UPPERCASE_LETTER},
                                                            {0x0101, 0x0101, UNICODE_LOWERCASE_LETTER},
                                                            {0x0102, 0x0102, UNICODE_UPPERCASE_LETTER},
                                                            {0x0103, 0x0103, UNICODE_LOWERCASE_LETTER},
                                                            {0x0104, 0x0104, UNICODE_UPPERCASE_LETTER},
                                                            {0x0105, 0x0105, UNICODE_LOWERCASE_LETTER},
                                                            {0x0106, 0x0106, UNICODE_UPPERCASE_LETTER},
                                                            {0x0107, 0x0107, UNICODE_LOWERCASE_LETTER},
                                                            {0x0108, 0x0108, UNICODE_UPPERCASE_LETTER},
                                                            {0x0109, 0x0109, UNICODE_LOWERCASE_LETTER},
                                                            {0x010A, 0x010A, UNICODE_UPPERCASE_LETTER},
                                                            {0x010B, 0x010B, UNICODE_LOWERCASE_LETTER},
                                                            {0x010C, 0x010C, UNICODE_UPPERCASE_LETTER},
                                                            {0x010D, 0x010D, UNICODE_LOWERCASE_LETTER},
                                                            {0x010E, 0x010E, UNICODE_UPPERCASE_LETTER},
                                                            {0x010F, 0x010F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0110, 0x0110, UNICODE_UPPERCASE_LETTER},
                                                            {0x0111, 0x0111, UNICODE_LOWERCASE_LETTER},
                                                            {0x0112, 0x0112, UNICODE_UPPERCASE_LETTER},
                                                            {0x0113, 0x0113, UNICODE_LOWERCASE_LETTER},
                                                            {0x0114, 0x0114, UNICODE_UPPERCASE_LETTER},
                                                            {0x0115, 0x0115, UNICODE_LOWERCASE_LETTER},
                                                            {0x0116, 0x0116, UNICODE_UPPERCASE_LETTER},
                                                            {0x0117, 0x0117, UNICODE_LOWERCASE_LETTER},
                                                            {0x0118, 0x0118, UNICODE_UPPERCASE_LETTER},
                                                            {0x0119, 0x0119, UNICODE_LOWERCASE_LETTER},
                                                            {0x011A, 0x011A, UNICODE_UPPERCASE_LETTER},
                                                            {0x011B, 0x011B, UNICODE_LOWERCASE_LETTER},
                                                            {0x011C, 0x011C, UNICODE_UPPERCASE_LETTER},
                                                            {0x011D, 0x011D, UNICODE_LOWERCASE_LETTER},
                                                            {0x011E, 0x011E, UNICODE_UPPERCASE_LETTER},
                                                            {0x011F, 0x011F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0120, 0x0120, UNICODE_UPPERCASE_LETTER},
                                                            {0x0121, 0x0121, UNICODE_LOWERCASE_LETTER},
                                                            {0x0122, 0x0122, UNICODE_UPPERCASE_LETTER},
                                                            {0x0123, 0x0123, UNICODE_LOWERCASE_LETTER},
                                                            {0x0124, 0x0124, UNICODE_UPPERCASE_LETTER},
                                                            {0x0125, 0x0125, UNICODE_LOWERCASE_LETTER},
                                                            {0x0126, 0x0126, UNICODE_UPPERCASE_LETTER},
                                                            {0x0127, 0x0127, UNICODE_LOWERCASE_LETTER},
                                                            {0x0128, 0x0128, UNICODE_UPPERCASE_LETTER},
                                                            {0x0129, 0x0129, UNICODE_LOWERCASE_LETTER},
                                                            {0x012A, 0x012A, UNICODE_UPPERCASE_LETTER},
                                                            {0x012B, 0x012B, UNICODE_LOWERCASE_LETTER},
                                                            {0x012C, 0x012C, UNICODE_UPPERCASE_LETTER},
                                                            {0x012D, 0x012D, UNICODE_LOWERCASE_LETTER},
                                                            {0x012E, 0x012E, UNICODE_UPPERCASE_LETTER},
                                                            {0x012F, 0x012F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0130, 0x0130, UNICODE_UPPERCASE_LETTER},
                                                            {0x0131, 0x0131, UNICODE_LOWERCASE_LETTER},
                                                            {0x0132, 0x0132, UNICODE_UPPERCASE_LETTER},
                                                            {0x0133, 0x0133, UNICODE_LOWERCASE_LETTER},
                                                            {0x0134, 0x0134, UNICODE_UPPERCASE_LETTER},
                                                            {0x0135, 0x0135, UNICODE_LOWERCASE_LETTER},
                                                            {0x0136, 0x0136, UNICODE_UPPERCASE_LETTER},
                                                            {0x0137, 0x0138, UNICODE_LOWERCASE_LETTER},
                                                            {0x0139, 0x0139, UNICODE_UPPERCASE_LETTER},
                                                            {0x013A, 0x013A, UNICODE_LOWERCASE_LETTER},
                                                            {0x013B, 0x013B, UNICODE_UPPERCASE_LETTER},
                                                            {0x013C, 0x013C, UNICODE_LOWERCASE_LETTER},
                                                            {0x013D, 0x013D, UNICODE_UPPERCASE_LETTER},
                                                            {0x013E, 0x013E, UNICODE_LOWERCASE_LETTER},
                                                            {0x013F, 0x013F, UNICODE_UPPERCASE_LETTER},
                                                            {0x0140, 0x0140, UNICODE_LOWERCASE_LETTER},
                                                            {0x0141, 0x0141, UNICODE_UPPERCASE_LETTER},
                                                            {0x0142, 0x0142, UNICODE_LOWERCASE_LETTER},
                                                            {0x0143, 0x0143, UNICODE_UPPERCASE_LETTER},
                                                            {0x0144, 0x0144, UNICODE_LOWERCASE_LETTER},
                                                            {0x0145, 0x0145, UNICODE_UPPERCASE_LETTER},
                                                            {0x0146, 0x0146, UNICODE_LOWERCASE_LETTER},
                                                            {0x0147, 0x0147, UNICODE_UPPERCASE_LETTER},
                                                            {0x0148, 0x0149, UNICODE_LOWERCASE_LETTER},
                                                            {0x014A, 0x014A, UNICODE_UPPERCASE_LETTER},
                                                            {0x014B, 0x014B, UNICODE_LOWERCASE_LETTER},
                                                            {0x014C, 0x014C, UNICODE_UPPERCASE_LETTER},
                                                            {0x014D, 0x014D, UNICODE_LOWERCASE_LETTER},
                                                            {0x014E, 0x014E, UNICODE_UPPERCASE_LETTER},
                                                            {0x014F, 0x014F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0150, 0x0150, UNICODE_UPPERCASE_LETTER},
                                                            {0x0151, 0x0151, UNICODE_LOWERCASE_LETTER},
                                                            {0x0152, 0x0152, UNICODE_UPPERCASE_LETTER},
                                                            {0x0153, 0x0153, UNICODE_LOWERCASE_LETTER},
                                                            {0x0154, 0x0154, UNICODE_UPPERCASE_LETTER},
                                                            {0x0155, 0x0155, UNICODE_LOWERCASE_LETTER},
                                                            {0x0156, 0x0156, UNICODE_UPPERCASE_LETTER},
                                                            {0x0157, 0x0157, UNICODE_LOWERCASE_LETTER},
                                                            {0x0158, 0x0158, UNICODE_UPPERCASE_LETTER},
                                                            {0x0159, 0x0159, UNICODE_LOWERCASE_LETTER},
                                                            {0x015A, 0x015A, UNICODE_UPPERCASE_LETTER},
                                                            {0x015B, 0x015B, UNICODE_LOWERCASE_LETTER},
                                                            {0x015C, 0x015C, UNICODE_UPPERCASE_LETTER},
                                                            {0x015D, 0x015D, UNICODE_LOWERCASE_LETTER},
                                                            {0x015E, 0x015E, UNICODE_UPPERCASE_LETTER},
                                                            {0x015F, 0x015F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0160, 0x0160, UNICODE_UPPERCASE_LETTER},
                                                            {0x0161, 0x0161, UNICODE_LOWERCASE_LETTER},
                                                            {0x0162, 0x0162, UNICODE_UPPERCASE_LETTER},
                                                            {0x0163, 0x0163, UNICODE_LOWERCASE_LETTER},
                                                            {0x0164, 0x0164, UNICODE_UPPERCASE_LETTER},
                                                            {0x0165, 0x0165, UNICODE_LOWERCASE_LETTER},
                                                            {0x0166, 0x0166, UNICODE_UPPERCASE_LETTER},
                                                            {0x0167, 0x0167, UNICODE_LOWERCASE_LETTER},
                                                            {0x0168, 0x0168, UNICODE_UPPERCASE_LETTER},
                                                            {0x0169, 0x0169, UNICODE_LOWERCASE_LETTER},
                                                            {0x016A, 0x016A, UNICODE_UPPERCASE_LETTER},
                                                            {0x016B, 0x016B, UNICODE_LOWERCASE_LETTER},
                                                            {0x016C, 0x016C, UNICODE_UPPERCASE_LETTER},
                                                            {0x016D, 0x016D, UNICODE_LOWERCASE_LETTER},
                                                            {0x016E, 0x016E, UNICODE_UPPERCASE_LETTER},
                                                            {0x016F, 0x016F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0170, 0x0170, UNICODE_UPPERCASE_LETTER},
                                                            {0x0171, 0x0171, UNICODE_LOWERCASE_LETTER},
                                                            {0x0172, 0x0172, UNICODE_UPPERCASE_LETTER},
                                                            {0x0173, 0x0173, UNICODE_LOWERCASE_LETTER},
                                                            {0x0174, 0x0174, UNICODE_UPPERCASE_LETTER},
                                                            {0x0175, 0x0175, UNICODE_LOWERCASE_LETTER},
                                                            {0x0176, 0x0176, UNICODE_UPPERCASE_LETTER},
                                                            {0x0177, 0x0177, UNICODE_LOWERCASE_LETTER},
                                                            {0x0178, 0x0179, UNICODE_UPPERCASE_LETTER},
                                                            {0x017A, 0x017A, UNICODE_LOWERCASE_LETTER},
                                                            {0x017B, 0x017B, UNICODE_UPPERCASE_LETTER},
                                                            {0x017C, 0x017C, UNICODE_LOWERCASE_LETTER},
                                                            {0x017D, 0x017D, UNICODE_UPPERCASE_LETTER},
                                                            {0x017E, 0x0180, UNICODE_LOWERCASE_LETTER},
                                                            {0x0181, 0x0182, UNICODE_UPPERCASE_LETTER},
                                                            {0x0183, 0x0183, UNICODE_LOWERCASE_LETTER},
                                                            {0x0184, 0x0184, UNICODE_UPPERCASE_LETTER},
                                                            {0x0185, 0x0185, UNICODE_LOWERCASE_LETTER},
                                                            {0x0186, 0x0187, UNICODE_UPPERCASE_LETTER},
                                                            {0x0188, 0x0188, UNICODE_LOWERCASE_LETTER},
                                                            {0x0189, 0x018B, UNICODE_UPPERCASE_LETTER},
                                                            {0x018C, 0x018D, UNICODE_LOWERCASE_LETTER},
                                                            {0x018E, 0x0191, UNICODE_UPPERCASE_LETTER},
                                                            {0x0192, 0x0192, UNICODE_LOWERCASE_LETTER},
                                                            {0x0193, 0x0194, UNICODE_UPPERCASE_LETTER},
                                                            {0x0195, 0x0195, UNICODE_LOWERCASE_LETTER},
                                                            {0x0196, 0x0198, UNICODE_UPPERCASE_LETTER},
                                                            {0x0199, 0x019B, UNICODE_LOWERCASE_LETTER},
                                                            {0x019C, 0x019D, UNICODE_UPPERCASE_LETTER},
                                                            {0x019E, 0x019E, UNICODE_LOWERCASE_LETTER},
                                                            {0x019F, 0x01A0, UNICODE_UPPERCASE_LETTER},
                                                            {0x01A1, 0x01A1, UNICODE_LOWERCASE_LETTER},
                                                            {0x01A2, 0x01A2, UNICODE_UPPERCASE_LETTER},
                                                            {0x01A3, 0x01A3, UNICODE_LOWERCASE_LETTER},
                                                            {0x01A4, 0x01A4, UNICODE_UPPERCASE_LETTER},
                                                            {0x01A5, 0x01A5, UNICODE_LOWERCASE_LETTER},
                                                            {0x01A6, 0x01A7, UNICODE_UPPERCASE_LETTER},
                                                            {0x01A8, 0x01A8, UNICODE_LOWERCASE_LETTER},
                                                            {0x01A9, 0x01A9, UNICODE_UPPERCASE_LETTER},
                                                            {0x01AA, 0x01AB, UNICODE_LOWERCASE_LETTER},
                                                            {0x01AC, 0x01AC, UNICODE_UPPERCASE_LETTER},
                                                            {0x01AD, 0x01AD, UNICODE_LOWERCASE_LETTER},
                                                            {0x01AE, 0x01AF, UNICODE_UPPERCASE_LETTER},
                                                            {0x01B0, 0x01B0, UNICODE_LOWERCASE_LETTER},
                                                            {0x01B1, 0x01B3, UNICODE_UPPERCASE_LETTER},
                                                            {0x01B4, 0x01B4, UNICODE_LOWERCASE_LETTER},
                                                            {0x01B5, 0x01B5, UNICODE_UPPERCASE_LETTER},
                                                            {0x01B6, 0x01B6, UNICODE_LOWERCASE_LETTER},
                                                            {0x01B7, 0x01B8, UNICODE_UPPERCASE_LETTER},
                                                            {0x01B9, 0x01BA, UNICODE_LOWERCASE_LETTER},
                                                            {0x01BB, 0x01BB, UNICODE_OTHER_LETTER},
                                                            {0x01BC, 0x01BC, UNICODE_UPPERCASE_LETTER},
                                                            {0x01BD, 0x01BF, UNICODE_LOWERCASE_LETTER},
                                                            {0x01C0, 0x01C3, UNICODE_OTHER_LETTER},
                                                            {0x01C4, 0x01C4, UNICODE_UPPERCASE_LETTER},
                                                            {0x01C5, 0x01C5, UNICODE_TITLECASE_LETTER},
                                                            {0x01C6, 0x01C6, UNICODE_LOWERCASE_LETTER},
                                                            {0x01C7, 0x01C7, UNICODE_UPPERCASE_LETTER},
                                                            {0x01C8, 0x01C8, UNICODE_TITLECASE_LETTER},
                                                            {0x01C9, 0x01C9, UNICODE_LOWERCASE_LETTER},
                                                            {0x01CA, 0x01CA, UNICODE_UPPERCASE_LETTER},
                                                            {0x01CB, 0x01CB, UNICODE_TITLECASE_LETTER},
                                                            {0x01CC, 0x01CC, UNICODE_LOWERCASE_LETTER},
                                                            {0x01CD, 0x01CD, UNICODE_UPPERCASE_LETTER},
                                                            {0x01CE, 0x01CE, UNICODE_LOWERCASE_LETTER},
                                                            {0x01CF, 0x01CF, UNICODE_UPPERCASE_LETTER},
                                                            {0x01D0, 0x01D0, UNICODE_LOWERCASE_LETTER},
                                                            {0x01D1, 0x01D1, UNICODE_UPPERCASE_LETTER},
                                                            {0x01D2, 0x01D2, UNICODE_LOWERCASE_LETTER},
                                                            {0x01D3, 0x01D3, UNICODE_UPPERCASE_LETTER},
                                                            {0x01D4, 0x01D4, UNICODE_LOWERCASE_LETTER},
                                                            {0x01D5, 0x01D5, UNICODE_UPPERCASE_LETTER},
                                                            {0x01D6, 0x01D6, UNICODE_LOWERCASE_LETTER},
                                                            {0x01D7, 0x01D7, UNICODE_UPPERCASE_LETTER},
                                                            {0x01D8, 0x01D8, UNICODE_LOWERCASE_LETTER},
                                                            {0x01D9, 0x01D9, UNICODE_UPPERCASE_LETTER},
                                                            {0x01DA, 0x01DA, UNICODE_LOWERCASE_LETTER},
                                                            {0x01DB, 0x01DB, UNICODE_UPPERCASE_LETTER},
                                                            {0x01DC, 0x01DD, UNICODE_LOWERCASE_LETTER},
                                                            {0x01DE, 0x01DE, UNICODE_UPPERCASE_LETTER},
                                                            {0x01DF, 0x01DF, UNICODE_LOWERCASE_LETTER},
                                                            {0x01E0, 0x01E0, UNICODE_UPPERCASE_LETTER},
                                                            {0x01E1, 0x01E1, UNICODE_LOWERCASE_LETTER},
                                                            {0x01E2, 0x01E2, UNICODE_UPPERCASE_LETTER},
                                                            {0x01E3, 0x01E3, UNICODE_LOWERCASE_LETTER},
                                                            {0x01E4, 0x01E4, UNICODE_UPPERCASE_LETTER},
                                                            {0x01E5, 0x01E5, UNICODE_LOWERCASE_LETTER},
                                                            {0x01E6, 0x01E6, UNICODE_UPPERCASE_LETTER},
                                                            {0x01E7, 0x01E7, UNICODE_LOWERCASE_LETTER},
                                                            {0x01E8, 0x01E8, UNICODE_UPPERCASE_LETTER},
                                                            {0x01E9, 0x01E9, UNICODE_LOWERCASE_LETTER},
                                                            {0x01EA, 0x01EA, UNICODE_UPPERCASE_LETTER},
                                                            {0x01EB, 0x01EB, UNICODE_LOWERCASE_LETTER},
                                                            {0x01EC, 0x01EC, UNICODE_UPPERCASE_LETTER},
                                                            {0x01ED, 0x01ED, UNICODE_LOWERCASE_LETTER},
                                                            {0x01EE, 0x01EE, UNICODE_UPPERCASE_LETTER},
                                                            {0x01EF, 0x01F0, UNICODE_LOWERCASE_LETTER},
                                                            {0x01F1, 0x01F1, UNICODE_UPPERCASE_LETTER},
                                                            {0x01F2, 0x01F2, UNICODE_TITLECASE_LETTER},
                                                            {0x01F3, 0x01F3, UNICODE_LOWERCASE_LETTER},
                                                            {0x01F4, 0x01F4, UNICODE_UPPERCASE_LETTER},
                                                            {0x01F5, 0x01F5, UNICODE_LOWERCASE_LETTER},
                                                            {0x01F6, 0x01F8, UNICODE_UPPERCASE_LETTER},
                                                            {0x01F9, 0x01F9, UNICODE_LOWERCASE_LETTER},
                                                            {0x01FA, 0x01FA, UNICODE_UPPERCASE_LETTER},
                                                            {0x01FB, 0x01FB, UNICODE_LOWERCASE_LETTER},
                                                            {0x01FC, 0x01FC, UNICODE_UPPERCASE_LETTER},
                                                            {0x01FD, 0x01FD, UNICODE_LOWERCASE_LETTER},
                                                            {0x01FE, 0x01FE, UNICODE_UPPERCASE_LETTER},
                                                            {0x01FF, 0x01FF, UNICODE_LOWERCASE_LETTER},
                                                            {0x0200, 0x0200, UNICODE_UPPERCASE_LETTER},
                                                            {0x0201, 0x0201, UNICODE_LOWERCASE_LETTER},
                                                            {0x0202, 0x0202, UNICODE_UPPERCASE_LETTER},
                                                            {0x0203, 0x0203, UNICODE_LOWERCASE_LETTER},
                                                            {0x0204, 0x0204, UNICODE_UPPERCASE_LETTER},
                                                            {0x0205, 0x0205, UNICODE_LOWERCASE_LETTER},
                                                            {0x0206, 0x0206, UNICODE_UPPERCASE_LETTER},
                                                            {0x0207, 0x0207, UNICODE_LOWERCASE_LETTER},
                                                            {0x0208, 0x0208, UNICODE_UPPERCASE_LETTER},
                                                            {0x0209, 0x0209, UNICODE_LOWERCASE_LETTER},
                                                            {0x020A, 0x020A, UNICODE_UPPERCASE_LETTER},
                                                            {0x020B, 0x020B, UNICODE_LOWERCASE_LETTER},
                                                            {0x020C, 0x020C, UNICODE_UPPERCASE_LETTER},
                                                            {0x020D, 0x020D, UNICODE_LOWERCASE_LETTER},
                                                            {0x020E, 0x020E, UNICODE_UPPERCASE_LETTER},
                                                            {0x020F, 0x020F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0210, 0x0210, UNICODE_UPPERCASE_LETTER},
                                                            {0x0211, 0x0211, UNICODE_LOWERCASE_LETTER},
                                                            {0x0212, 0x0212, UNICODE_UPPERCASE_LETTER},
                                                            {0x0213, 0x0213, UNICODE_LOWERCASE_LETTER},
                                                            {0x0214, 0x0214, UNICODE_UPPERCASE_LETTER},
                                                            {0x0215, 0x0215, UNICODE_LOWERCASE_LETTER},
                                                            {0x0216, 0x0216, UNICODE_UPPERCASE_LETTER},
                                                            {0x0217, 0x0217, UNICODE_LOWERCASE_LETTER},
                                                            {0x0218, 0x0218, UNICODE_UPPERCASE_LETTER},
                                                            {0x0219, 0x0219, UNICODE_LOWERCASE_LETTER},
                                                            {0x021A, 0x021A, UNICODE_UPPERCASE_LETTER},
                                                            {0x021B, 0x021B, UNICODE_LOWERCASE_LETTER},
                                                            {0x021C, 0x021C, UNICODE_UPPERCASE_LETTER},
                                                            {0x021D, 0x021D, UNICODE_LOWERCASE_LETTER},
                                                            {0x021E, 0x021E, UNICODE_UPPERCASE_LETTER},
                                                            {0x021F, 0x021F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0220, 0x0220, UNICODE_UPPERCASE_LETTER},
                                                            {0x0221, 0x0221, UNICODE_LOWERCASE_LETTER},
                                                            {0x0222, 0x0222, UNICODE_UPPERCASE_LETTER},
                                                            {0x0223, 0x0223, UNICODE_LOWERCASE_LETTER},
                                                            {0x0224, 0x0224, UNICODE_UPPERCASE_LETTER},
                                                            {0x0225, 0x0225, UNICODE_LOWERCASE_LETTER},
                                                            {0x0226, 0x0226, UNICODE_UPPERCASE_LETTER},
                                                            {0x0227, 0x0227, UNICODE_LOWERCASE_LETTER},
                                                            {0x0228, 0x0228, UNICODE_UPPERCASE_LETTER},
                                                            {0x0229, 0x0229, UNICODE_LOWERCASE_LETTER},
                                                            {0x022A, 0x022A, UNICODE_UPPERCASE_LETTER},
                                                            {0x022B, 0x022B, UNICODE_LOWERCASE_LETTER},
                                                            {0x022C, 0x022C, UNICODE_UPPERCASE_LETTER},
                                                            {0x022D, 0x022D, UNICODE_LOWERCASE_LETTER},
                                                            {0x022E, 0x022E, UNICODE_UPPERCASE_LETTER},
                                                            {0x022F, 0x022F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0230, 0x0230, UNICODE_UPPERCASE_LETTER},
                                                            {0x0231, 0x0231, UNICODE_LOWERCASE_LETTER},
                                                            {0x0232, 0x0232, UNICODE_UPPERCASE_LETTER},
                                                            {0x0233, 0x0239, UNICODE_LOWERCASE_LETTER},
                                                            {0x023A, 0x023B, UNICODE_UPPERCASE_LETTER},
                                                            {0x023C, 0x023C, UNICODE_LOWERCASE_LETTER},
                                                            {0x023D, 0x023E, UNICODE_UPPERCASE_LETTER},
                                                            {0x023F, 0x0240, UNICODE_LOWERCASE_LETTER},
                                                            {0x0241, 0x0241, UNICODE_UPPERCASE_LETTER},
                                                            {0x0242, 0x0242, UNICODE_LOWERCASE_LETTER},
                                                            {0x0243, 0x0246, UNICODE_UPPERCASE_LETTER},
                                                            {0x0247, 0x0247, UNICODE_LOWERCASE_LETTER},
                                                            {0x0248, 0x0248, UNICODE_UPPERCASE_LETTER},
                                                            {0x0249, 0x0249, UNICODE_LOWERCASE_LETTER},
                                                            {0x024A, 0x024A, UNICODE_UPPERCASE_LETTER},
                                                            {0x024B, 0x024B, UNICODE_LOWERCASE_LETTER},
                                                            {0x024C, 0x024C, UNICODE_UPPERCASE_LETTER},
                                                            {0x024D, 0x024D, UNICODE_LOWERCASE_LETTER},
                                                            {0x024E, 0x024E, UNICODE_UPPERCASE_LETTER},
                                                            {0x024F, 0x0293, UNICODE_LOWERCASE_LETTER},
                                                            {0x0294, 0x0294, UNICODE_OTHER_LETTER},
                                                            {0x0295, 0x02AF, UNICODE_LOWERCASE_LETTER},
                                                            {0x02B0, 0x02C1, UNICODE_MODIFIER_LETTER},
                                                            {0x02C2, 0x02C5, UNICODE_MODIFIER_SYMBOL},
                                                            {0x02C6, 0x02D1, UNICODE_MODIFIER_LETTER},
                                                            {0x02D2, 0x02DF, UNICODE_MODIFIER_SYMBOL},
                                                            {0x02E0, 0x02E4, UNICODE_MODIFIER_LETTER},
                                                            {0x02E5, 0x02ED, UNICODE_MODIFIER_SYMBOL},
                                                            {0x02EE, 0x02EE, UNICODE_MODIFIER_LETTER},
                                                            {0x02EF, 0x02FF, UNICODE_MODIFIER_SYMBOL},
                                                            {0x0300, 0x036F, UNICODE_NON_SPACING_MARK},
                                                            {0x0374, 0x0375, UNICODE_MODIFIER_SYMBOL},
                                                            {0x037A, 0x037A, UNICODE_MODIFIER_LETTER},
                                                            {0x037B, 0x037D, UNICODE_LOWERCASE_LETTER},
                                                            {0x037E, 0x037E, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0384, 0x0385, UNICODE_MODIFIER_SYMBOL},
                                                            {0x0386, 0x0386, UNICODE_UPPERCASE_LETTER},
                                                            {0x0387, 0x0387, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0388, 0x038A, UNICODE_UPPERCASE_LETTER},
                                                            {0x038C, 0x038C, UNICODE_UPPERCASE_LETTER},
                                                            {0x038E, 0x038F, UNICODE_UPPERCASE_LETTER},
                                                            {0x0390, 0x0390, UNICODE_LOWERCASE_LETTER},
                                                            {0x0391, 0x03A1, UNICODE_UPPERCASE_LETTER},
                                                            {0x03A3, 0x03AB, UNICODE_UPPERCASE_LETTER},
                                                            {0x03AC, 0x03CE, UNICODE_LOWERCASE_LETTER},
                                                            {0x03D0, 0x03D1, UNICODE_LOWERCASE_LETTER},
                                                            {0x03D2, 0x03D4, UNICODE_UPPERCASE_LETTER},
                                                            {0x03D5, 0x03D7, UNICODE_LOWERCASE_LETTER},
                                                            {0x03D8, 0x03D8, UNICODE_UPPERCASE_LETTER},
                                                            {0x03D9, 0x03D9, UNICODE_LOWERCASE_LETTER},
                                                            {0x03DA, 0x03DA, UNICODE_UPPERCASE_LETTER},
                                                            {0x03DB, 0x03DB, UNICODE_LOWERCASE_LETTER},
                                                            {0x03DC, 0x03DC, UNICODE_UPPERCASE_LETTER},
                                                            {0x03DD, 0x03DD, UNICODE_LOWERCASE_LETTER},
                                                            {0x03DE, 0x03DE, UNICODE_UPPERCASE_LETTER},
                                                            {0x03DF, 0x03DF, UNICODE_LOWERCASE_LETTER},
                                                            {0x03E0, 0x03E0, UNICODE_UPPERCASE_LETTER},
                                                            {0x03E1, 0x03E1, UNICODE_LOWERCASE_LETTER},
                                                            {0x03E2, 0x03E2, UNICODE_UPPERCASE_LETTER},
                                                            {0x03E3, 0x03E3, UNICODE_LOWERCASE_LETTER},
                                                            {0x03E4, 0x03E4, UNICODE_UPPERCASE_LETTER},
                                                            {0x03E5, 0x03E5, UNICODE_LOWERCASE_LETTER},
                                                            {0x03E6, 0x03E6, UNICODE_UPPERCASE_LETTER},
                                                            {0x03E7, 0x03E7, UNICODE_LOWERCASE_LETTER},
                                                            {0x03E8, 0x03E8, UNICODE_UPPERCASE_LETTER},
                                                            {0x03E9, 0x03E9, UNICODE_LOWERCASE_LETTER},
                                                            {0x03EA, 0x03EA, UNICODE_UPPERCASE_LETTER},
                                                            {0x03EB, 0x03EB, UNICODE_LOWERCASE_LETTER},
                                                            {0x03EC, 0x03EC, UNICODE_UPPERCASE_LETTER},
                                                            {0x03ED, 0x03ED, UNICODE_LOWERCASE_LETTER},
                                                            {0x03EE, 0x03EE, UNICODE_UPPERCASE_LETTER},
                                                            {0x03EF, 0x03F3, UNICODE_LOWERCASE_LETTER},
                                                            {0x03F4, 0x03F4, UNICODE_UPPERCASE_LETTER},
                                                            {0x03F5, 0x03F5, UNICODE_LOWERCASE_LETTER},
                                                            {0x03F6, 0x03F6, UNICODE_MATH_SYMBOL},
                                                            {0x03F7, 0x03F7, UNICODE_UPPERCASE_LETTER},
                                                            {0x03F8, 0x03F8, UNICODE_LOWERCASE_LETTER},
                                                            {0x03F9, 0x03FA, UNICODE_UPPERCASE_LETTER},
                                                            {0x03FB, 0x03FC, UNICODE_LOWERCASE_LETTER},
                                                            {0x03FD, 0x042F, UNICODE_UPPERCASE_LETTER},
                                                            {0x0430, 0x045F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0460, 0x0460, UNICODE_UPPERCASE_LETTER},
                                                            {0x0461, 0x0461, UNICODE_LOWERCASE_LETTER},
                                                            {0x0462, 0x0462, UNICODE_UPPERCASE_LETTER},
                                                            {0x0463, 0x0463, UNICODE_LOWERCASE_LETTER},
                                                            {0x0464, 0x0464, UNICODE_UPPERCASE_LETTER},
                                                            {0x0465, 0x0465, UNICODE_LOWERCASE_LETTER},
                                                            {0x0466, 0x0466, UNICODE_UPPERCASE_LETTER},
                                                            {0x0467, 0x0467, UNICODE_LOWERCASE_LETTER},
                                                            {0x0468, 0x0468, UNICODE_UPPERCASE_LETTER},
                                                            {0x0469, 0x0469, UNICODE_LOWERCASE_LETTER},
                                                            {0x046A, 0x046A, UNICODE_UPPERCASE_LETTER},
                                                            {0x046B, 0x046B, UNICODE_LOWERCASE_LETTER},
                                                            {0x046C, 0x046C, UNICODE_UPPERCASE_LETTER},
                                                            {0x046D, 0x046D, UNICODE_LOWERCASE_LETTER},
                                                            {0x046E, 0x046E, UNICODE_UPPERCASE_LETTER},
                                                            {0x046F, 0x046F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0470, 0x0470, UNICODE_UPPERCASE_LETTER},
                                                            {0x0471, 0x0471, UNICODE_LOWERCASE_LETTER},
                                                            {0x0472, 0x0472, UNICODE_UPPERCASE_LETTER},
                                                            {0x0473, 0x0473, UNICODE_LOWERCASE_LETTER},
                                                            {0x0474, 0x0474, UNICODE_UPPERCASE_LETTER},
                                                            {0x0475, 0x0475, UNICODE_LOWERCASE_LETTER},
                                                            {0x0476, 0x0476, UNICODE_UPPERCASE_LETTER},
                                                            {0x0477, 0x0477, UNICODE_LOWERCASE_LETTER},
                                                            {0x0478, 0x0478, UNICODE_UPPERCASE_LETTER},
                                                            {0x0479, 0x0479, UNICODE_LOWERCASE_LETTER},
                                                            {0x047A, 0x047A, UNICODE_UPPERCASE_LETTER},
                                                            {0x047B, 0x047B, UNICODE_LOWERCASE_LETTER},
                                                            {0x047C, 0x047C, UNICODE_UPPERCASE_LETTER},
                                                            {0x047D, 0x047D, UNICODE_LOWERCASE_LETTER},
                                                            {0x047E, 0x047E, UNICODE_UPPERCASE_LETTER},
                                                            {0x047F, 0x047F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0480, 0x0480, UNICODE_UPPERCASE_LETTER},
                                                            {0x0481, 0x0481, UNICODE_LOWERCASE_LETTER},
                                                            {0x0482, 0x0482, UNICODE_OTHER_SYMBOL},
                                                            {0x0483, 0x0486, UNICODE_NON_SPACING_MARK},
                                                            {0x0488, 0x0489, UNICODE_ENCLOSING_MARK},
                                                            {0x048A, 0x048A, UNICODE_UPPERCASE_LETTER},
                                                            {0x048B, 0x048B, UNICODE_LOWERCASE_LETTER},
                                                            {0x048C, 0x048C, UNICODE_UPPERCASE_LETTER},
                                                            {0x048D, 0x048D, UNICODE_LOWERCASE_LETTER},
                                                            {0x048E, 0x048E, UNICODE_UPPERCASE_LETTER},
                                                            {0x048F, 0x048F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0490, 0x0490, UNICODE_UPPERCASE_LETTER},
                                                            {0x0491, 0x0491, UNICODE_LOWERCASE_LETTER},
                                                            {0x0492, 0x0492, UNICODE_UPPERCASE_LETTER},
                                                            {0x0493, 0x0493, UNICODE_LOWERCASE_LETTER},
                                                            {0x0494, 0x0494, UNICODE_UPPERCASE_LETTER},
                                                            {0x0495, 0x0495, UNICODE_LOWERCASE_LETTER},
                                                            {0x0496, 0x0496, UNICODE_UPPERCASE_LETTER},
                                                            {0x0497, 0x0497, UNICODE_LOWERCASE_LETTER},
                                                            {0x0498, 0x0498, UNICODE_UPPERCASE_LETTER},
                                                            {0x0499, 0x0499, UNICODE_LOWERCASE_LETTER},
                                                            {0x049A, 0x049A, UNICODE_UPPERCASE_LETTER},
                                                            {0x049B, 0x049B, UNICODE_LOWERCASE_LETTER},
                                                            {0x049C, 0x049C, UNICODE_UPPERCASE_LETTER},
                                                            {0x049D, 0x049D, UNICODE_LOWERCASE_LETTER},
                                                            {0x049E, 0x049E, UNICODE_UPPERCASE_LETTER},
                                                            {0x049F, 0x049F, UNICODE_LOWERCASE_LETTER},
                                                            {0x04A0, 0x04A0, UNICODE_UPPERCASE_LETTER},
                                                            {0x04A1, 0x04A1, UNICODE_LOWERCASE_LETTER},
                                                            {0x04A2, 0x04A2, UNICODE_UPPERCASE_LETTER},
                                                            {0x04A3, 0x04A3, UNICODE_LOWERCASE_LETTER},
                                                            {0x04A4, 0x04A4, UNICODE_UPPERCASE_LETTER},
                                                            {0x04A5, 0x04A5, UNICODE_LOWERCASE_LETTER},
                                                            {0x04A6, 0x04A6, UNICODE_UPPERCASE_LETTER},
                                                            {0x04A7, 0x04A7, UNICODE_LOWERCASE_LETTER},
                                                            {0x04A8, 0x04A8, UNICODE_UPPERCASE_LETTER},
                                                            {0x04A9, 0x04A9, UNICODE_LOWERCASE_LETTER},
                                                            {0x04AA, 0x04AA, UNICODE_UPPERCASE_LETTER},
                                                            {0x04AB, 0x04AB, UNICODE_LOWERCASE_LETTER},
                                                            {0x04AC, 0x04AC, UNICODE_UPPERCASE_LETTER},
                                                            {0x04AD, 0x04AD, UNICODE_LOWERCASE_LETTER},
                                                            {0x04AE, 0x04AE, UNICODE_UPPERCASE_LETTER},
                                                            {0x04AF, 0x04AF, UNICODE_LOWERCASE_LETTER},
                                                            {0x04B0, 0x04B0, UNICODE_UPPERCASE_LETTER},
                                                            {0x04B1, 0x04B1, UNICODE_LOWERCASE_LETTER},
                                                            {0x04B2, 0x04B2, UNICODE_UPPERCASE_LETTER},
                                                            {0x04B3, 0x04B3, UNICODE_LOWERCASE_LETTER},
                                                            {0x04B4, 0x04B4, UNICODE_UPPERCASE_LETTER},
                                                            {0x04B5, 0x04B5, UNICODE_LOWERCASE_LETTER},
                                                            {0x04B6, 0x04B6, UNICODE_UPPERCASE_LETTER},
                                                            {0x04B7, 0x04B7, UNICODE_LOWERCASE_LETTER},
                                                            {0x04B8, 0x04B8, UNICODE_UPPERCASE_LETTER},
                                                            {0x04B9, 0x04B9, UNICODE_LOWERCASE_LETTER},
                                                            {0x04BA, 0x04BA, UNICODE_UPPERCASE_LETTER},
                                                            {0x04BB, 0x04BB, UNICODE_LOWERCASE_LETTER},
                                                            {0x04BC, 0x04BC, UNICODE_UPPERCASE_LETTER},
                                                            {0x04BD, 0x04BD, UNICODE_LOWERCASE_LETTER},
                                                            {0x04BE, 0x04BE, UNICODE_UPPERCASE_LETTER},
                                                            {0x04BF, 0x04BF, UNICODE_LOWERCASE_LETTER},
                                                            {0x04C0, 0x04C1, UNICODE_UPPERCASE_LETTER},
                                                            {0x04C2, 0x04C2, UNICODE_LOWERCASE_LETTER},
                                                            {0x04C3, 0x04C3, UNICODE_UPPERCASE_LETTER},
                                                            {0x04C4, 0x04C4, UNICODE_LOWERCASE_LETTER},
                                                            {0x04C5, 0x04C5, UNICODE_UPPERCASE_LETTER},
                                                            {0x04C6, 0x04C6, UNICODE_LOWERCASE_LETTER},
                                                            {0x04C7, 0x04C7, UNICODE_UPPERCASE_LETTER},
                                                            {0x04C8, 0x04C8, UNICODE_LOWERCASE_LETTER},
                                                            {0x04C9, 0x04C9, UNICODE_UPPERCASE_LETTER},
                                                            {0x04CA, 0x04CA, UNICODE_LOWERCASE_LETTER},
                                                            {0x04CB, 0x04CB, UNICODE_UPPERCASE_LETTER},
                                                            {0x04CC, 0x04CC, UNICODE_LOWERCASE_LETTER},
                                                            {0x04CD, 0x04CD, UNICODE_UPPERCASE_LETTER},
                                                            {0x04CE, 0x04CF, UNICODE_LOWERCASE_LETTER},
                                                            {0x04D0, 0x04D0, UNICODE_UPPERCASE_LETTER},
                                                            {0x04D1, 0x04D1, UNICODE_LOWERCASE_LETTER},
                                                            {0x04D2, 0x04D2, UNICODE_UPPERCASE_LETTER},
                                                            {0x04D3, 0x04D3, UNICODE_LOWERCASE_LETTER},
                                                            {0x04D4, 0x04D4, UNICODE_UPPERCASE_LETTER},
                                                            {0x04D5, 0x04D5, UNICODE_LOWERCASE_LETTER},
                                                            {0x04D6, 0x04D6, UNICODE_UPPERCASE_LETTER},
                                                            {0x04D7, 0x04D7, UNICODE_LOWERCASE_LETTER},
                                                            {0x04D8, 0x04D8, UNICODE_UPPERCASE_LETTER},
                                                            {0x04D9, 0x04D9, UNICODE_LOWERCASE_LETTER},
                                                            {0x04DA, 0x04DA, UNICODE_UPPERCASE_LETTER},
                                                            {0x04DB, 0x04DB, UNICODE_LOWERCASE_LETTER},
                                                            {0x04DC, 0x04DC, UNICODE_UPPERCASE_LETTER},
                                                            {0x04DD, 0x04DD, UNICODE_LOWERCASE_LETTER},
                                                            {0x04DE, 0x04DE, UNICODE_UPPERCASE_LETTER},
                                                            {0x04DF, 0x04DF, UNICODE_LOWERCASE_LETTER},
                                                            {0x04E0, 0x04E0, UNICODE_UPPERCASE_LETTER},
                                                            {0x04E1, 0x04E1, UNICODE_LOWERCASE_LETTER},
                                                            {0x04E2, 0x04E2, UNICODE_UPPERCASE_LETTER},
                                                            {0x04E3, 0x04E3, UNICODE_LOWERCASE_LETTER},
                                                            {0x04E4, 0x04E4, UNICODE_UPPERCASE_LETTER},
                                                            {0x04E5, 0x04E5, UNICODE_LOWERCASE_LETTER},
                                                            {0x04E6, 0x04E6, UNICODE_UPPERCASE_LETTER},
                                                            {0x04E7, 0x04E7, UNICODE_LOWERCASE_LETTER},
                                                            {0x04E8, 0x04E8, UNICODE_UPPERCASE_LETTER},
                                                            {0x04E9, 0x04E9, UNICODE_LOWERCASE_LETTER},
                                                            {0x04EA, 0x04EA, UNICODE_UPPERCASE_LETTER},
                                                            {0x04EB, 0x04EB, UNICODE_LOWERCASE_LETTER},
                                                            {0x04EC, 0x04EC, UNICODE_UPPERCASE_LETTER},
                                                            {0x04ED, 0x04ED, UNICODE_LOWERCASE_LETTER},
                                                            {0x04EE, 0x04EE, UNICODE_UPPERCASE_LETTER},
                                                            {0x04EF, 0x04EF, UNICODE_LOWERCASE_LETTER},
                                                            {0x04F0, 0x04F0, UNICODE_UPPERCASE_LETTER},
                                                            {0x04F1, 0x04F1, UNICODE_LOWERCASE_LETTER},
                                                            {0x04F2, 0x04F2, UNICODE_UPPERCASE_LETTER},
                                                            {0x04F3, 0x04F3, UNICODE_LOWERCASE_LETTER},
                                                            {0x04F4, 0x04F4, UNICODE_UPPERCASE_LETTER},
                                                            {0x04F5, 0x04F5, UNICODE_LOWERCASE_LETTER},
                                                            {0x04F6, 0x04F6, UNICODE_UPPERCASE_LETTER},
                                                            {0x04F7, 0x04F7, UNICODE_LOWERCASE_LETTER},
                                                            {0x04F8, 0x04F8, UNICODE_UPPERCASE_LETTER},
                                                            {0x04F9, 0x04F9, UNICODE_LOWERCASE_LETTER},
                                                            {0x04FA, 0x04FA, UNICODE_UPPERCASE_LETTER},
                                                            {0x04FB, 0x04FB, UNICODE_LOWERCASE_LETTER},
                                                            {0x04FC, 0x04FC, UNICODE_UPPERCASE_LETTER},
                                                            {0x04FD, 0x04FD, UNICODE_LOWERCASE_LETTER},
                                                            {0x04FE, 0x04FE, UNICODE_UPPERCASE_LETTER},
                                                            {0x04FF, 0x04FF, UNICODE_LOWERCASE_LETTER},
                                                            {0x0500, 0x0500, UNICODE_UPPERCASE_LETTER},
                                                            {0x0501, 0x0501, UNICODE_LOWERCASE_LETTER},
                                                            {0x0502, 0x0502, UNICODE_UPPERCASE_LETTER},
                                                            {0x0503, 0x0503, UNICODE_LOWERCASE_LETTER},
                                                            {0x0504, 0x0504, UNICODE_UPPERCASE_LETTER},
                                                            {0x0505, 0x0505, UNICODE_LOWERCASE_LETTER},
                                                            {0x0506, 0x0506, UNICODE_UPPERCASE_LETTER},
                                                            {0x0507, 0x0507, UNICODE_LOWERCASE_LETTER},
                                                            {0x0508, 0x0508, UNICODE_UPPERCASE_LETTER},
                                                            {0x0509, 0x0509, UNICODE_LOWERCASE_LETTER},
                                                            {0x050A, 0x050A, UNICODE_UPPERCASE_LETTER},
                                                            {0x050B, 0x050B, UNICODE_LOWERCASE_LETTER},
                                                            {0x050C, 0x050C, UNICODE_UPPERCASE_LETTER},
                                                            {0x050D, 0x050D, UNICODE_LOWERCASE_LETTER},
                                                            {0x050E, 0x050E, UNICODE_UPPERCASE_LETTER},
                                                            {0x050F, 0x050F, UNICODE_LOWERCASE_LETTER},
                                                            {0x0510, 0x0510, UNICODE_UPPERCASE_LETTER},
                                                            {0x0511, 0x0511, UNICODE_LOWERCASE_LETTER},
                                                            {0x0512, 0x0512, UNICODE_UPPERCASE_LETTER},
                                                            {0x0513, 0x0513, UNICODE_LOWERCASE_LETTER},
                                                            {0x0531, 0x0556, UNICODE_UPPERCASE_LETTER},
                                                            {0x0559, 0x0559, UNICODE_MODIFIER_LETTER},
                                                            {0x055A, 0x055F, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0561, 0x0587, UNICODE_LOWERCASE_LETTER},
                                                            {0x0589, 0x0589, UNICODE_OTHER_PUNCTUATION},
                                                            {0x058A, 0x058A, UNICODE_DASH_PUNCTUATION},
                                                            {0x0591, 0x05BD, UNICODE_NON_SPACING_MARK},
                                                            {0x05BE, 0x05BE, UNICODE_OTHER_PUNCTUATION},
                                                            {0x05BF, 0x05BF, UNICODE_NON_SPACING_MARK},
                                                            {0x05C0, 0x05C0, UNICODE_OTHER_PUNCTUATION},
                                                            {0x05C1, 0x05C2, UNICODE_NON_SPACING_MARK},
                                                            {0x05C3, 0x05C3, UNICODE_OTHER_PUNCTUATION},
                                                            {0x05C4, 0x05C5, UNICODE_NON_SPACING_MARK},
                                                            {0x05C6, 0x05C6, UNICODE_OTHER_PUNCTUATION},
                                                            {0x05C7, 0x05C7, UNICODE_NON_SPACING_MARK},
                                                            {0x05D0, 0x05EA, UNICODE_OTHER_LETTER},
                                                            {0x05F0, 0x05F2, UNICODE_OTHER_LETTER},
                                                            {0x05F3, 0x05F4, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0600, 0x0603, UNICODE_FORMAT},
                                                            {0x060B, 0x060B, UNICODE_CURRENCY_SYMBOL},
                                                            {0x060C, 0x060D, UNICODE_OTHER_PUNCTUATION},
                                                            {0x060E, 0x060F, UNICODE_OTHER_SYMBOL},
                                                            {0x0610, 0x0615, UNICODE_NON_SPACING_MARK},
                                                            {0x061B, 0x061B, UNICODE_OTHER_PUNCTUATION},
                                                            {0x061E, 0x061F, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0621, 0x063A, UNICODE_OTHER_LETTER},
                                                            {0x0640, 0x0640, UNICODE_MODIFIER_LETTER},
                                                            {0x0641, 0x064A, UNICODE_OTHER_LETTER},
                                                            {0x064B, 0x065E, UNICODE_NON_SPACING_MARK},
                                                            {0x0660, 0x0669, UNICODE_DECIMAL_NUMBER},
                                                            {0x066A, 0x066D, UNICODE_OTHER_PUNCTUATION},
                                                            {0x066E, 0x066F, UNICODE_OTHER_LETTER},
                                                            {0x0670, 0x0670, UNICODE_NON_SPACING_MARK},
                                                            {0x0671, 0x06D3, UNICODE_OTHER_LETTER},
                                                            {0x06D4, 0x06D4, UNICODE_OTHER_PUNCTUATION},
                                                            {0x06D5, 0x06D5, UNICODE_OTHER_LETTER},
                                                            {0x06D6, 0x06DC, UNICODE_NON_SPACING_MARK},
                                                            {0x06DD, 0x06DD, UNICODE_FORMAT},
                                                            {0x06DE, 0x06DE, UNICODE_ENCLOSING_MARK},
                                                            {0x06DF, 0x06E4, UNICODE_NON_SPACING_MARK},
                                                            {0x06E5, 0x06E6, UNICODE_MODIFIER_LETTER},
                                                            {0x06E7, 0x06E8, UNICODE_NON_SPACING_MARK},
                                                            {0x06E9, 0x06E9, UNICODE_OTHER_SYMBOL},
                                                            {0x06EA, 0x06ED, UNICODE_NON_SPACING_MARK},
                                                            {0x06EE, 0x06EF, UNICODE_OTHER_LETTER},
                                                            {0x06F0, 0x06F9, UNICODE_DECIMAL_NUMBER},
                                                            {0x06FA, 0x06FC, UNICODE_OTHER_LETTER},
                                                            {0x06FD, 0x06FE, UNICODE_OTHER_SYMBOL},
                                                            {0x06FF, 0x06FF, UNICODE_OTHER_LETTER},
                                                            {0x0700, 0x070D, UNICODE_OTHER_PUNCTUATION},
                                                            {0x070F, 0x070F, UNICODE_FORMAT},
                                                            {0x0710, 0x0710, UNICODE_OTHER_LETTER},
                                                            {0x0711, 0x0711, UNICODE_NON_SPACING_MARK},
                                                            {0x0712, 0x072F, UNICODE_OTHER_LETTER},
                                                            {0x0730, 0x074A, UNICODE_NON_SPACING_MARK},
                                                            {0x074D, 0x076D, UNICODE_OTHER_LETTER},
                                                            {0x0780, 0x07A5, UNICODE_OTHER_LETTER},
                                                            {0x07A6, 0x07B0, UNICODE_NON_SPACING_MARK},
                                                            {0x07B1, 0x07B1, UNICODE_OTHER_LETTER},
                                                            {0x07C0, 0x07C9, UNICODE_DECIMAL_NUMBER},
                                                            {0x07CA, 0x07EA, UNICODE_OTHER_LETTER},
                                                            {0x07EB, 0x07F3, UNICODE_NON_SPACING_MARK},
                                                            {0x07F4, 0x07F5, UNICODE_MODIFIER_LETTER},
                                                            {0x07F6, 0x07F6, UNICODE_OTHER_SYMBOL},
                                                            {0x07F7, 0x07F9, UNICODE_OTHER_PUNCTUATION},
                                                            {0x07FA, 0x07FA, UNICODE_MODIFIER_LETTER},
                                                            {0x0901, 0x0902, UNICODE_NON_SPACING_MARK},
                                                            {0x0903, 0x0903, UNICODE_COMBINING_MARK},
                                                            {0x0904, 0x0939, UNICODE_OTHER_LETTER},
                                                            {0x093C, 0x093C, UNICODE_NON_SPACING_MARK},
                                                            {0x093D, 0x093D, UNICODE_OTHER_LETTER},
                                                            {0x093E, 0x0940, UNICODE_COMBINING_MARK},
                                                            {0x0941, 0x0948, UNICODE_NON_SPACING_MARK},
                                                            {0x0949, 0x094C, UNICODE_COMBINING_MARK},
                                                            {0x094D, 0x094D, UNICODE_NON_SPACING_MARK},
                                                            {0x0950, 0x0950, UNICODE_OTHER_LETTER},
                                                            {0x0951, 0x0954, UNICODE_NON_SPACING_MARK},
                                                            {0x0958, 0x0961, UNICODE_OTHER_LETTER},
                                                            {0x0962, 0x0963, UNICODE_NON_SPACING_MARK},
                                                            {0x0964, 0x0965, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0966, 0x096F, UNICODE_DECIMAL_NUMBER},
                                                            {0x0970, 0x0970, UNICODE_OTHER_PUNCTUATION},
                                                            {0x097B, 0x097F, UNICODE_OTHER_LETTER},
                                                            {0x0981, 0x0981, UNICODE_NON_SPACING_MARK},
                                                            {0x0982, 0x0983, UNICODE_COMBINING_MARK},
                                                            {0x0985, 0x098C, UNICODE_OTHER_LETTER},
                                                            {0x098F, 0x0990, UNICODE_OTHER_LETTER},
                                                            {0x0993, 0x09A8, UNICODE_OTHER_LETTER},
                                                            {0x09AA, 0x09B0, UNICODE_OTHER_LETTER},
                                                            {0x09B2, 0x09B2, UNICODE_OTHER_LETTER},
                                                            {0x09B6, 0x09B9, UNICODE_OTHER_LETTER},
                                                            {0x09BC, 0x09BC, UNICODE_NON_SPACING_MARK},
                                                            {0x09BD, 0x09BD, UNICODE_OTHER_LETTER},
                                                            {0x09BE, 0x09C0, UNICODE_COMBINING_MARK},
                                                            {0x09C1, 0x09C4, UNICODE_NON_SPACING_MARK},
                                                            {0x09C7, 0x09C8, UNICODE_COMBINING_MARK},
                                                            {0x09CB, 0x09CC, UNICODE_COMBINING_MARK},
                                                            {0x09CD, 0x09CD, UNICODE_NON_SPACING_MARK},
                                                            {0x09CE, 0x09CE, UNICODE_OTHER_LETTER},
                                                            {0x09D7, 0x09D7, UNICODE_COMBINING_MARK},
                                                            {0x09DC, 0x09DD, UNICODE_OTHER_LETTER},
                                                            {0x09DF, 0x09E1, UNICODE_OTHER_LETTER},
                                                            {0x09E2, 0x09E3, UNICODE_NON_SPACING_MARK},
                                                            {0x09E6, 0x09EF, UNICODE_DECIMAL_NUMBER},
                                                            {0x09F0, 0x09F1, UNICODE_OTHER_LETTER},
                                                            {0x09F2, 0x09F3, UNICODE_CURRENCY_SYMBOL},
                                                            {0x09F4, 0x09F9, UNICODE_OTHER_NUMBER},
                                                            {0x09FA, 0x09FA, UNICODE_OTHER_SYMBOL},
                                                            {0x0A01, 0x0A02, UNICODE_NON_SPACING_MARK},
                                                            {0x0A03, 0x0A03, UNICODE_COMBINING_MARK},
                                                            {0x0A05, 0x0A0A, UNICODE_OTHER_LETTER},
                                                            {0x0A0F, 0x0A10, UNICODE_OTHER_LETTER},
                                                            {0x0A13, 0x0A28, UNICODE_OTHER_LETTER},
                                                            {0x0A2A, 0x0A30, UNICODE_OTHER_LETTER},
                                                            {0x0A32, 0x0A33, UNICODE_OTHER_LETTER},
                                                            {0x0A35, 0x0A36, UNICODE_OTHER_LETTER},
                                                            {0x0A38, 0x0A39, UNICODE_OTHER_LETTER},
                                                            {0x0A3C, 0x0A3C, UNICODE_NON_SPACING_MARK},
                                                            {0x0A3E, 0x0A40, UNICODE_COMBINING_MARK},
                                                            {0x0A41, 0x0A42, UNICODE_NON_SPACING_MARK},
                                                            {0x0A47, 0x0A48, UNICODE_NON_SPACING_MARK},
                                                            {0x0A4B, 0x0A4D, UNICODE_NON_SPACING_MARK},
                                                            {0x0A59, 0x0A5C, UNICODE_OTHER_LETTER},
                                                            {0x0A5E, 0x0A5E, UNICODE_OTHER_LETTER},
                                                            {0x0A66, 0x0A6F, UNICODE_DECIMAL_NUMBER},
                                                            {0x0A70, 0x0A71, UNICODE_NON_SPACING_MARK},
                                                            {0x0A72, 0x0A74, UNICODE_OTHER_LETTER},
                                                            {0x0A81, 0x0A82, UNICODE_NON_SPACING_MARK},
                                                            {0x0A83, 0x0A83, UNICODE_COMBINING_MARK},
                                                            {0x0A85, 0x0A8D, UNICODE_OTHER_LETTER},
                                                            {0x0A8F, 0x0A91, UNICODE_OTHER_LETTER},
                                                            {0x0A93, 0x0AA8, UNICODE_OTHER_LETTER},
                                                            {0x0AAA, 0x0AB0, UNICODE_OTHER_LETTER},
                                                            {0x0AB2, 0x0AB3, UNICODE_OTHER_LETTER},
                                                            {0x0AB5, 0x0AB9, UNICODE_OTHER_LETTER},
                                                            {0x0ABC, 0x0ABC, UNICODE_NON_SPACING_MARK},
                                                            {0x0ABD, 0x0ABD, UNICODE_OTHER_LETTER},
                                                            {0x0ABE, 0x0AC0, UNICODE_COMBINING_MARK},
                                                            {0x0AC1, 0x0AC5, UNICODE_NON_SPACING_MARK},
                                                            {0x0AC7, 0x0AC8, UNICODE_NON_SPACING_MARK},
                                                            {0x0AC9, 0x0AC9, UNICODE_COMBINING_MARK},
                                                            {0x0ACB, 0x0ACC, UNICODE_COMBINING_MARK},
                                                            {0x0ACD, 0x0ACD, UNICODE_NON_SPACING_MARK},
                                                            {0x0AD0, 0x0AD0, UNICODE_OTHER_LETTER},
                                                            {0x0AE0, 0x0AE1, UNICODE_OTHER_LETTER},
                                                            {0x0AE2, 0x0AE3, UNICODE_NON_SPACING_MARK},
                                                            {0x0AE6, 0x0AEF, UNICODE_DECIMAL_NUMBER},
                                                            {0x0AF1, 0x0AF1, UNICODE_CURRENCY_SYMBOL},
                                                            {0x0B01, 0x0B01, UNICODE_NON_SPACING_MARK},
                                                            {0x0B02, 0x0B03, UNICODE_COMBINING_MARK},
                                                            {0x0B05, 0x0B0C, UNICODE_OTHER_LETTER},
                                                            {0x0B0F, 0x0B10, UNICODE_OTHER_LETTER},
                                                            {0x0B13, 0x0B28, UNICODE_OTHER_LETTER},
                                                            {0x0B2A, 0x0B30, UNICODE_OTHER_LETTER},
                                                            {0x0B32, 0x0B33, UNICODE_OTHER_LETTER},
                                                            {0x0B35, 0x0B39, UNICODE_OTHER_LETTER},
                                                            {0x0B3C, 0x0B3C, UNICODE_NON_SPACING_MARK},
                                                            {0x0B3D, 0x0B3D, UNICODE_OTHER_LETTER},
                                                            {0x0B3E, 0x0B3E, UNICODE_COMBINING_MARK},
                                                            {0x0B3F, 0x0B3F, UNICODE_NON_SPACING_MARK},
                                                            {0x0B40, 0x0B40, UNICODE_COMBINING_MARK},
                                                            {0x0B41, 0x0B43, UNICODE_NON_SPACING_MARK},
                                                            {0x0B47, 0x0B48, UNICODE_COMBINING_MARK},
                                                            {0x0B4B, 0x0B4C, UNICODE_COMBINING_MARK},
                                                            {0x0B4D, 0x0B4D, UNICODE_NON_SPACING_MARK},
                                                            {0x0B56, 0x0B56, UNICODE_NON_SPACING_MARK},
                                                            {0x0B57, 0x0B57, UNICODE_COMBINING_MARK},
                                                            {0x0B5C, 0x0B5D, UNICODE_OTHER_LETTER},
                                                            {0x0B5F, 0x0B61, UNICODE_OTHER_LETTER},
                                                            {0x0B66, 0x0B6F, UNICODE_DECIMAL_NUMBER},
                                                            {0x0B70, 0x0B70, UNICODE_OTHER_SYMBOL},
                                                            {0x0B71, 0x0B71, UNICODE_OTHER_LETTER},
                                                            {0x0B82, 0x0B82, UNICODE_NON_SPACING_MARK},
                                                            {0x0B83, 0x0B83, UNICODE_OTHER_LETTER},
                                                            {0x0B85, 0x0B8A, UNICODE_OTHER_LETTER},
                                                            {0x0B8E, 0x0B90, UNICODE_OTHER_LETTER},
                                                            {0x0B92, 0x0B95, UNICODE_OTHER_LETTER},
                                                            {0x0B99, 0x0B9A, UNICODE_OTHER_LETTER},
                                                            {0x0B9C, 0x0B9C, UNICODE_OTHER_LETTER},
                                                            {0x0B9E, 0x0B9F, UNICODE_OTHER_LETTER},
                                                            {0x0BA3, 0x0BA4, UNICODE_OTHER_LETTER},
                                                            {0x0BA8, 0x0BAA, UNICODE_OTHER_LETTER},
                                                            {0x0BAE, 0x0BB9, UNICODE_OTHER_LETTER},
                                                            {0x0BBE, 0x0BBF, UNICODE_COMBINING_MARK},
                                                            {0x0BC0, 0x0BC0, UNICODE_NON_SPACING_MARK},
                                                            {0x0BC1, 0x0BC2, UNICODE_COMBINING_MARK},
                                                            {0x0BC6, 0x0BC8, UNICODE_COMBINING_MARK},
                                                            {0x0BCA, 0x0BCC, UNICODE_COMBINING_MARK},
                                                            {0x0BCD, 0x0BCD, UNICODE_NON_SPACING_MARK},
                                                            {0x0BD7, 0x0BD7, UNICODE_COMBINING_MARK},
                                                            {0x0BE6, 0x0BEF, UNICODE_DECIMAL_NUMBER},
                                                            {0x0BF0, 0x0BF2, UNICODE_OTHER_NUMBER},
                                                            {0x0BF3, 0x0BF8, UNICODE_OTHER_SYMBOL},
                                                            {0x0BF9, 0x0BF9, UNICODE_CURRENCY_SYMBOL},
                                                            {0x0BFA, 0x0BFA, UNICODE_OTHER_SYMBOL},
                                                            {0x0C01, 0x0C03, UNICODE_COMBINING_MARK},
                                                            {0x0C05, 0x0C0C, UNICODE_OTHER_LETTER},
                                                            {0x0C0E, 0x0C10, UNICODE_OTHER_LETTER},
                                                            {0x0C12, 0x0C28, UNICODE_OTHER_LETTER},
                                                            {0x0C2A, 0x0C33, UNICODE_OTHER_LETTER},
                                                            {0x0C35, 0x0C39, UNICODE_OTHER_LETTER},
                                                            {0x0C3E, 0x0C40, UNICODE_NON_SPACING_MARK},
                                                            {0x0C41, 0x0C44, UNICODE_COMBINING_MARK},
                                                            {0x0C46, 0x0C48, UNICODE_NON_SPACING_MARK},
                                                            {0x0C4A, 0x0C4D, UNICODE_NON_SPACING_MARK},
                                                            {0x0C55, 0x0C56, UNICODE_NON_SPACING_MARK},
                                                            {0x0C60, 0x0C61, UNICODE_OTHER_LETTER},
                                                            {0x0C66, 0x0C6F, UNICODE_DECIMAL_NUMBER},
                                                            {0x0C82, 0x0C83, UNICODE_COMBINING_MARK},
                                                            {0x0C85, 0x0C8C, UNICODE_OTHER_LETTER},
                                                            {0x0C8E, 0x0C90, UNICODE_OTHER_LETTER},
                                                            {0x0C92, 0x0CA8, UNICODE_OTHER_LETTER},
                                                            {0x0CAA, 0x0CB3, UNICODE_OTHER_LETTER},
                                                            {0x0CB5, 0x0CB9, UNICODE_OTHER_LETTER},
                                                            {0x0CBC, 0x0CBC, UNICODE_NON_SPACING_MARK},
                                                            {0x0CBD, 0x0CBD, UNICODE_OTHER_LETTER},
                                                            {0x0CBE, 0x0CBE, UNICODE_COMBINING_MARK},
                                                            {0x0CBF, 0x0CBF, UNICODE_NON_SPACING_MARK},
                                                            {0x0CC0, 0x0CC4, UNICODE_COMBINING_MARK},
                                                            {0x0CC6, 0x0CC6, UNICODE_NON_SPACING_MARK},
                                                            {0x0CC7, 0x0CC8, UNICODE_COMBINING_MARK},
                                                            {0x0CCA, 0x0CCB, UNICODE_COMBINING_MARK},
                                                            {0x0CCC, 0x0CCD, UNICODE_NON_SPACING_MARK},
                                                            {0x0CD5, 0x0CD6, UNICODE_COMBINING_MARK},
                                                            {0x0CDE, 0x0CDE, UNICODE_OTHER_LETTER},
                                                            {0x0CE0, 0x0CE1, UNICODE_OTHER_LETTER},
                                                            {0x0CE2, 0x0CE3, UNICODE_NON_SPACING_MARK},
                                                            {0x0CE6, 0x0CEF, UNICODE_DECIMAL_NUMBER},
                                                            {0x0CF1, 0x0CF2, UNICODE_OTHER_SYMBOL},
                                                            {0x0D02, 0x0D03, UNICODE_COMBINING_MARK},
                                                            {0x0D05, 0x0D0C, UNICODE_OTHER_LETTER},
                                                            {0x0D0E, 0x0D10, UNICODE_OTHER_LETTER},
                                                            {0x0D12, 0x0D28, UNICODE_OTHER_LETTER},
                                                            {0x0D2A, 0x0D39, UNICODE_OTHER_LETTER},
                                                            {0x0D3E, 0x0D40, UNICODE_COMBINING_MARK},
                                                            {0x0D41, 0x0D43, UNICODE_NON_SPACING_MARK},
                                                            {0x0D46, 0x0D48, UNICODE_COMBINING_MARK},
                                                            {0x0D4A, 0x0D4C, UNICODE_COMBINING_MARK},
                                                            {0x0D4D, 0x0D4D, UNICODE_NON_SPACING_MARK},
                                                            {0x0D57, 0x0D57, UNICODE_COMBINING_MARK},
                                                            {0x0D60, 0x0D61, UNICODE_OTHER_LETTER},
                                                            {0x0D66, 0x0D6F, UNICODE_DECIMAL_NUMBER},
                                                            {0x0D82, 0x0D83, UNICODE_COMBINING_MARK},
                                                            {0x0D85, 0x0D96, UNICODE_OTHER_LETTER},
                                                            {0x0D9A, 0x0DB1, UNICODE_OTHER_LETTER},
                                                            {0x0DB3, 0x0DBB, UNICODE_OTHER_LETTER},
                                                            {0x0DBD, 0x0DBD, UNICODE_OTHER_LETTER},
                                                            {0x0DC0, 0x0DC6, UNICODE_OTHER_LETTER},
                                                            {0x0DCA, 0x0DCA, UNICODE_NON_SPACING_MARK},
                                                            {0x0DCF, 0x0DD1, UNICODE_COMBINING_MARK},
                                                            {0x0DD2, 0x0DD4, UNICODE_NON_SPACING_MARK},
                                                            {0x0DD6, 0x0DD6, UNICODE_NON_SPACING_MARK},
                                                            {0x0DD8, 0x0DDF, UNICODE_COMBINING_MARK},
                                                            {0x0DF2, 0x0DF3, UNICODE_COMBINING_MARK},
                                                            {0x0DF4, 0x0DF4, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0E01, 0x0E30, UNICODE_OTHER_LETTER},
                                                            {0x0E31, 0x0E31, UNICODE_NON_SPACING_MARK},
                                                            {0x0E32, 0x0E33, UNICODE_OTHER_LETTER},
                                                            {0x0E34, 0x0E3A, UNICODE_NON_SPACING_MARK},
                                                            {0x0E3F, 0x0E3F, UNICODE_CURRENCY_SYMBOL},
                                                            {0x0E40, 0x0E45, UNICODE_OTHER_LETTER},
                                                            {0x0E46, 0x0E46, UNICODE_MODIFIER_LETTER},
                                                            {0x0E47, 0x0E4E, UNICODE_NON_SPACING_MARK},
                                                            {0x0E4F, 0x0E4F, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0E50, 0x0E59, UNICODE_DECIMAL_NUMBER},
                                                            {0x0E5A, 0x0E5B, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0E81, 0x0E82, UNICODE_OTHER_LETTER},
                                                            {0x0E84, 0x0E84, UNICODE_OTHER_LETTER},
                                                            {0x0E87, 0x0E88, UNICODE_OTHER_LETTER},
                                                            {0x0E8A, 0x0E8A, UNICODE_OTHER_LETTER},
                                                            {0x0E8D, 0x0E8D, UNICODE_OTHER_LETTER},
                                                            {0x0E94, 0x0E97, UNICODE_OTHER_LETTER},
                                                            {0x0E99, 0x0E9F, UNICODE_OTHER_LETTER},
                                                            {0x0EA1, 0x0EA3, UNICODE_OTHER_LETTER},
                                                            {0x0EA5, 0x0EA5, UNICODE_OTHER_LETTER},
                                                            {0x0EA7, 0x0EA7, UNICODE_OTHER_LETTER},
                                                            {0x0EAA, 0x0EAB, UNICODE_OTHER_LETTER},
                                                            {0x0EAD, 0x0EB0, UNICODE_OTHER_LETTER},
                                                            {0x0EB1, 0x0EB1, UNICODE_NON_SPACING_MARK},
                                                            {0x0EB2, 0x0EB3, UNICODE_OTHER_LETTER},
                                                            {0x0EB4, 0x0EB9, UNICODE_NON_SPACING_MARK},
                                                            {0x0EBB, 0x0EBC, UNICODE_NON_SPACING_MARK},
                                                            {0x0EBD, 0x0EBD, UNICODE_OTHER_LETTER},
                                                            {0x0EC0, 0x0EC4, UNICODE_OTHER_LETTER},
                                                            {0x0EC6, 0x0EC6, UNICODE_MODIFIER_LETTER},
                                                            {0x0EC8, 0x0ECD, UNICODE_NON_SPACING_MARK},
                                                            {0x0ED0, 0x0ED9, UNICODE_DECIMAL_NUMBER},
                                                            {0x0EDC, 0x0EDD, UNICODE_OTHER_LETTER},
                                                            {0x0F00, 0x0F00, UNICODE_OTHER_LETTER},
                                                            {0x0F01, 0x0F03, UNICODE_OTHER_SYMBOL},
                                                            {0x0F04, 0x0F12, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0F13, 0x0F17, UNICODE_OTHER_SYMBOL},
                                                            {0x0F18, 0x0F19, UNICODE_NON_SPACING_MARK},
                                                            {0x0F1A, 0x0F1F, UNICODE_OTHER_SYMBOL},
                                                            {0x0F20, 0x0F29, UNICODE_DECIMAL_NUMBER},
                                                            {0x0F2A, 0x0F33, UNICODE_OTHER_NUMBER},
                                                            {0x0F34, 0x0F34, UNICODE_OTHER_SYMBOL},
                                                            {0x0F35, 0x0F35, UNICODE_NON_SPACING_MARK},
                                                            {0x0F36, 0x0F36, UNICODE_OTHER_SYMBOL},
                                                            {0x0F37, 0x0F37, UNICODE_NON_SPACING_MARK},
                                                            {0x0F38, 0x0F38, UNICODE_OTHER_SYMBOL},
                                                            {0x0F39, 0x0F39, UNICODE_NON_SPACING_MARK},
                                                            {0x0F3A, 0x0F3A, UNICODE_OPEN_PUNCTUATION},
                                                            {0x0F3B, 0x0F3B, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x0F3C, 0x0F3C, UNICODE_OPEN_PUNCTUATION},
                                                            {0x0F3D, 0x0F3D, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x0F3E, 0x0F3F, UNICODE_COMBINING_MARK},
                                                            {0x0F40, 0x0F47, UNICODE_OTHER_LETTER},
                                                            {0x0F49, 0x0F6A, UNICODE_OTHER_LETTER},
                                                            {0x0F71, 0x0F7E, UNICODE_NON_SPACING_MARK},
                                                            {0x0F7F, 0x0F7F, UNICODE_COMBINING_MARK},
                                                            {0x0F80, 0x0F84, UNICODE_NON_SPACING_MARK},
                                                            {0x0F85, 0x0F85, UNICODE_OTHER_PUNCTUATION},
                                                            {0x0F86, 0x0F87, UNICODE_NON_SPACING_MARK},
                                                            {0x0F88, 0x0F8B, UNICODE_OTHER_LETTER},
                                                            {0x0F90, 0x0F97, UNICODE_NON_SPACING_MARK},
                                                            {0x0F99, 0x0FBC, UNICODE_NON_SPACING_MARK},
                                                            {0x0FBE, 0x0FC5, UNICODE_OTHER_SYMBOL},
                                                            {0x0FC6, 0x0FC6, UNICODE_NON_SPACING_MARK},
                                                            {0x0FC7, 0x0FCC, UNICODE_OTHER_SYMBOL},
                                                            {0x0FCF, 0x0FCF, UNICODE_OTHER_SYMBOL},
                                                            {0x0FD0, 0x0FD1, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1000, 0x1021, UNICODE_OTHER_LETTER},
                                                            {0x1023, 0x1027, UNICODE_OTHER_LETTER},
                                                            {0x1029, 0x102A, UNICODE_OTHER_LETTER},
                                                            {0x102C, 0x102C, UNICODE_COMBINING_MARK},
                                                            {0x102D, 0x1030, UNICODE_NON_SPACING_MARK},
                                                            {0x1031, 0x1031, UNICODE_COMBINING_MARK},
                                                            {0x1032, 0x1032, UNICODE_NON_SPACING_MARK},
                                                            {0x1036, 0x1037, UNICODE_NON_SPACING_MARK},
                                                            {0x1038, 0x1038, UNICODE_COMBINING_MARK},
                                                            {0x1039, 0x1039, UNICODE_NON_SPACING_MARK},
                                                            {0x1040, 0x1049, UNICODE_DECIMAL_NUMBER},
                                                            {0x104A, 0x104F, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1050, 0x1055, UNICODE_OTHER_LETTER},
                                                            {0x1056, 0x1057, UNICODE_COMBINING_MARK},
                                                            {0x1058, 0x1059, UNICODE_NON_SPACING_MARK},
                                                            {0x10A0, 0x10C5, UNICODE_UPPERCASE_LETTER},
                                                            {0x10D0, 0x10FA, UNICODE_OTHER_LETTER},
                                                            {0x10FB, 0x10FB, UNICODE_OTHER_PUNCTUATION},
                                                            {0x10FC, 0x10FC, UNICODE_MODIFIER_LETTER},
                                                            {0x1100, 0x1159, UNICODE_OTHER_LETTER},
                                                            {0x115F, 0x11A2, UNICODE_OTHER_LETTER},
                                                            {0x11A8, 0x11F9, UNICODE_OTHER_LETTER},
                                                            {0x1200, 0x1248, UNICODE_OTHER_LETTER},
                                                            {0x124A, 0x124D, UNICODE_OTHER_LETTER},
                                                            {0x1250, 0x1256, UNICODE_OTHER_LETTER},
                                                            {0x1258, 0x1258, UNICODE_OTHER_LETTER},
                                                            {0x125A, 0x125D, UNICODE_OTHER_LETTER},
                                                            {0x1260, 0x1288, UNICODE_OTHER_LETTER},
                                                            {0x128A, 0x128D, UNICODE_OTHER_LETTER},
                                                            {0x1290, 0x12B0, UNICODE_OTHER_LETTER},
                                                            {0x12B2, 0x12B5, UNICODE_OTHER_LETTER},
                                                            {0x12B8, 0x12BE, UNICODE_OTHER_LETTER},
                                                            {0x12C0, 0x12C0, UNICODE_OTHER_LETTER},
                                                            {0x12C2, 0x12C5, UNICODE_OTHER_LETTER},
                                                            {0x12C8, 0x12D6, UNICODE_OTHER_LETTER},
                                                            {0x12D8, 0x1310, UNICODE_OTHER_LETTER},
                                                            {0x1312, 0x1315, UNICODE_OTHER_LETTER},
                                                            {0x1318, 0x135A, UNICODE_OTHER_LETTER},
                                                            {0x135F, 0x135F, UNICODE_NON_SPACING_MARK},
                                                            {0x1360, 0x1360, UNICODE_OTHER_SYMBOL},
                                                            {0x1361, 0x1368, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1369, 0x137C, UNICODE_OTHER_NUMBER},
                                                            {0x1380, 0x138F, UNICODE_OTHER_LETTER},
                                                            {0x1390, 0x1399, UNICODE_OTHER_SYMBOL},
                                                            {0x13A0, 0x13F4, UNICODE_OTHER_LETTER},
                                                            {0x1401, 0x166C, UNICODE_OTHER_LETTER},
                                                            {0x166D, 0x166E, UNICODE_OTHER_PUNCTUATION},
                                                            {0x166F, 0x1676, UNICODE_OTHER_LETTER},
                                                            {0x1680, 0x1680, UNICODE_SPACE_SEPARATOR},
                                                            {0x1681, 0x169A, UNICODE_OTHER_LETTER},
                                                            {0x169B, 0x169B, UNICODE_OPEN_PUNCTUATION},
                                                            {0x169C, 0x169C, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x16A0, 0x16EA, UNICODE_OTHER_LETTER},
                                                            {0x16EB, 0x16ED, UNICODE_OTHER_PUNCTUATION},
                                                            {0x16EE, 0x16F0, UNICODE_LETTER_NUMBER},
                                                            {0x1700, 0x170C, UNICODE_OTHER_LETTER},
                                                            {0x170E, 0x1711, UNICODE_OTHER_LETTER},
                                                            {0x1712, 0x1714, UNICODE_NON_SPACING_MARK},
                                                            {0x1720, 0x1731, UNICODE_OTHER_LETTER},
                                                            {0x1732, 0x1734, UNICODE_NON_SPACING_MARK},
                                                            {0x1735, 0x1736, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1740, 0x1751, UNICODE_OTHER_LETTER},
                                                            {0x1752, 0x1753, UNICODE_NON_SPACING_MARK},
                                                            {0x1760, 0x176C, UNICODE_OTHER_LETTER},
                                                            {0x176E, 0x1770, UNICODE_OTHER_LETTER},
                                                            {0x1772, 0x1773, UNICODE_NON_SPACING_MARK},
                                                            {0x1780, 0x17B3, UNICODE_OTHER_LETTER},
                                                            {0x17B4, 0x17B5, UNICODE_FORMAT},
                                                            {0x17B6, 0x17B6, UNICODE_COMBINING_MARK},
                                                            {0x17B7, 0x17BD, UNICODE_NON_SPACING_MARK},
                                                            {0x17BE, 0x17C5, UNICODE_COMBINING_MARK},
                                                            {0x17C6, 0x17C6, UNICODE_NON_SPACING_MARK},
                                                            {0x17C7, 0x17C8, UNICODE_COMBINING_MARK},
                                                            {0x17C9, 0x17D3, UNICODE_NON_SPACING_MARK},
                                                            {0x17D4, 0x17D6, UNICODE_OTHER_PUNCTUATION},
                                                            {0x17D7, 0x17D7, UNICODE_MODIFIER_LETTER},
                                                            {0x17D8, 0x17DA, UNICODE_OTHER_PUNCTUATION},
                                                            {0x17DB, 0x17DB, UNICODE_CURRENCY_SYMBOL},
                                                            {0x17DC, 0x17DC, UNICODE_OTHER_LETTER},
                                                            {0x17DD, 0x17DD, UNICODE_NON_SPACING_MARK},
                                                            {0x17E0, 0x17E9, UNICODE_DECIMAL_NUMBER},
                                                            {0x17F0, 0x17F9, UNICODE_OTHER_NUMBER},
                                                            {0x1800, 0x1805, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1806, 0x1806, UNICODE_DASH_PUNCTUATION},
                                                            {0x1807, 0x180A, UNICODE_OTHER_PUNCTUATION},
                                                            {0x180B, 0x180D, UNICODE_NON_SPACING_MARK},
                                                            {0x180E, 0x180E, UNICODE_SPACE_SEPARATOR},
                                                            {0x1810, 0x1819, UNICODE_DECIMAL_NUMBER},
                                                            {0x1820, 0x1842, UNICODE_OTHER_LETTER},
                                                            {0x1843, 0x1843, UNICODE_MODIFIER_LETTER},
                                                            {0x1844, 0x1877, UNICODE_OTHER_LETTER},
                                                            {0x1880, 0x18A8, UNICODE_OTHER_LETTER},
                                                            {0x18A9, 0x18A9, UNICODE_NON_SPACING_MARK},
                                                            {0x1900, 0x191C, UNICODE_OTHER_LETTER},
                                                            {0x1920, 0x1922, UNICODE_NON_SPACING_MARK},
                                                            {0x1923, 0x1926, UNICODE_COMBINING_MARK},
                                                            {0x1927, 0x1928, UNICODE_NON_SPACING_MARK},
                                                            {0x1929, 0x192B, UNICODE_COMBINING_MARK},
                                                            {0x1930, 0x1931, UNICODE_COMBINING_MARK},
                                                            {0x1932, 0x1932, UNICODE_NON_SPACING_MARK},
                                                            {0x1933, 0x1938, UNICODE_COMBINING_MARK},
                                                            {0x1939, 0x193B, UNICODE_NON_SPACING_MARK},
                                                            {0x1940, 0x1940, UNICODE_OTHER_SYMBOL},
                                                            {0x1944, 0x1945, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1946, 0x194F, UNICODE_DECIMAL_NUMBER},
                                                            {0x1950, 0x196D, UNICODE_OTHER_LETTER},
                                                            {0x1970, 0x1974, UNICODE_OTHER_LETTER},
                                                            {0x1980, 0x19A9, UNICODE_OTHER_LETTER},
                                                            {0x19B0, 0x19C0, UNICODE_COMBINING_MARK},
                                                            {0x19C1, 0x19C7, UNICODE_OTHER_LETTER},
                                                            {0x19C8, 0x19C9, UNICODE_COMBINING_MARK},
                                                            {0x19D0, 0x19D9, UNICODE_DECIMAL_NUMBER},
                                                            {0x19DE, 0x19DF, UNICODE_OTHER_PUNCTUATION},
                                                            {0x19E0, 0x19FF, UNICODE_OTHER_SYMBOL},
                                                            {0x1A00, 0x1A16, UNICODE_OTHER_LETTER},
                                                            {0x1A17, 0x1A18, UNICODE_NON_SPACING_MARK},
                                                            {0x1A19, 0x1A1B, UNICODE_COMBINING_MARK},
                                                            {0x1A1E, 0x1A1F, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1B00, 0x1B03, UNICODE_NON_SPACING_MARK},
                                                            {0x1B04, 0x1B04, UNICODE_COMBINING_MARK},
                                                            {0x1B05, 0x1B33, UNICODE_OTHER_LETTER},
                                                            {0x1B34, 0x1B34, UNICODE_NON_SPACING_MARK},
                                                            {0x1B35, 0x1B35, UNICODE_COMBINING_MARK},
                                                            {0x1B36, 0x1B3A, UNICODE_NON_SPACING_MARK},
                                                            {0x1B3B, 0x1B3B, UNICODE_COMBINING_MARK},
                                                            {0x1B3C, 0x1B3C, UNICODE_NON_SPACING_MARK},
                                                            {0x1B3D, 0x1B41, UNICODE_COMBINING_MARK},
                                                            {0x1B42, 0x1B42, UNICODE_NON_SPACING_MARK},
                                                            {0x1B43, 0x1B44, UNICODE_COMBINING_MARK},
                                                            {0x1B45, 0x1B4B, UNICODE_OTHER_LETTER},
                                                            {0x1B50, 0x1B59, UNICODE_DECIMAL_NUMBER},
                                                            {0x1B5A, 0x1B60, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1B61, 0x1B6A, UNICODE_OTHER_SYMBOL},
                                                            {0x1B6B, 0x1B73, UNICODE_NON_SPACING_MARK},
                                                            {0x1B74, 0x1B7C, UNICODE_OTHER_SYMBOL},
                                                            {0x1D00, 0x1D2B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D2C, 0x1D61, UNICODE_MODIFIER_LETTER},
                                                            {0x1D62, 0x1D77, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D78, 0x1D78, UNICODE_MODIFIER_LETTER},
                                                            {0x1D79, 0x1D9A, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D9B, 0x1DBF, UNICODE_MODIFIER_LETTER},
                                                            {0x1DC0, 0x1DCA, UNICODE_NON_SPACING_MARK},
                                                            {0x1DFE, 0x1DFF, UNICODE_NON_SPACING_MARK},
                                                            {0x1E00, 0x1E00, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E01, 0x1E01, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E02, 0x1E02, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E03, 0x1E03, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E04, 0x1E04, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E05, 0x1E05, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E06, 0x1E06, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E07, 0x1E07, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E08, 0x1E08, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E09, 0x1E09, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E0A, 0x1E0A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E0B, 0x1E0B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E0C, 0x1E0C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E0D, 0x1E0D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E0E, 0x1E0E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E0F, 0x1E0F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E10, 0x1E10, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E11, 0x1E11, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E12, 0x1E12, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E13, 0x1E13, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E14, 0x1E14, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E15, 0x1E15, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E16, 0x1E16, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E17, 0x1E17, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E18, 0x1E18, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E19, 0x1E19, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E1A, 0x1E1A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E1B, 0x1E1B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E1C, 0x1E1C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E1D, 0x1E1D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E1E, 0x1E1E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E1F, 0x1E1F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E20, 0x1E20, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E21, 0x1E21, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E22, 0x1E22, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E23, 0x1E23, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E24, 0x1E24, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E25, 0x1E25, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E26, 0x1E26, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E27, 0x1E27, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E28, 0x1E28, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E29, 0x1E29, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E2A, 0x1E2A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E2B, 0x1E2B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E2C, 0x1E2C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E2D, 0x1E2D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E2E, 0x1E2E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E2F, 0x1E2F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E30, 0x1E30, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E31, 0x1E31, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E32, 0x1E32, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E33, 0x1E33, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E34, 0x1E34, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E35, 0x1E35, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E36, 0x1E36, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E37, 0x1E37, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E38, 0x1E38, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E39, 0x1E39, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E3A, 0x1E3A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E3B, 0x1E3B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E3C, 0x1E3C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E3D, 0x1E3D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E3E, 0x1E3E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E3F, 0x1E3F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E40, 0x1E40, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E41, 0x1E41, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E42, 0x1E42, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E43, 0x1E43, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E44, 0x1E44, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E45, 0x1E45, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E46, 0x1E46, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E47, 0x1E47, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E48, 0x1E48, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E49, 0x1E49, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E4A, 0x1E4A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E4B, 0x1E4B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E4C, 0x1E4C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E4D, 0x1E4D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E4E, 0x1E4E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E4F, 0x1E4F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E50, 0x1E50, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E51, 0x1E51, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E52, 0x1E52, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E53, 0x1E53, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E54, 0x1E54, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E55, 0x1E55, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E56, 0x1E56, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E57, 0x1E57, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E58, 0x1E58, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E59, 0x1E59, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E5A, 0x1E5A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E5B, 0x1E5B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E5C, 0x1E5C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E5D, 0x1E5D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E5E, 0x1E5E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E5F, 0x1E5F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E60, 0x1E60, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E61, 0x1E61, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E62, 0x1E62, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E63, 0x1E63, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E64, 0x1E64, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E65, 0x1E65, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E66, 0x1E66, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E67, 0x1E67, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E68, 0x1E68, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E69, 0x1E69, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E6A, 0x1E6A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E6B, 0x1E6B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E6C, 0x1E6C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E6D, 0x1E6D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E6E, 0x1E6E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E6F, 0x1E6F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E70, 0x1E70, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E71, 0x1E71, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E72, 0x1E72, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E73, 0x1E73, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E74, 0x1E74, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E75, 0x1E75, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E76, 0x1E76, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E77, 0x1E77, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E78, 0x1E78, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E79, 0x1E79, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E7A, 0x1E7A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E7B, 0x1E7B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E7C, 0x1E7C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E7D, 0x1E7D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E7E, 0x1E7E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E7F, 0x1E7F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E80, 0x1E80, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E81, 0x1E81, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E82, 0x1E82, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E83, 0x1E83, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E84, 0x1E84, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E85, 0x1E85, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E86, 0x1E86, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E87, 0x1E87, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E88, 0x1E88, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E89, 0x1E89, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E8A, 0x1E8A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E8B, 0x1E8B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E8C, 0x1E8C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E8D, 0x1E8D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E8E, 0x1E8E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E8F, 0x1E8F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E90, 0x1E90, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E91, 0x1E91, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E92, 0x1E92, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E93, 0x1E93, UNICODE_LOWERCASE_LETTER},
                                                            {0x1E94, 0x1E94, UNICODE_UPPERCASE_LETTER},
                                                            {0x1E95, 0x1E9B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EA0, 0x1EA0, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EA1, 0x1EA1, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EA2, 0x1EA2, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EA3, 0x1EA3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EA4, 0x1EA4, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EA5, 0x1EA5, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EA6, 0x1EA6, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EA7, 0x1EA7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EA8, 0x1EA8, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EA9, 0x1EA9, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EAA, 0x1EAA, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EAB, 0x1EAB, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EAC, 0x1EAC, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EAD, 0x1EAD, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EAE, 0x1EAE, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EAF, 0x1EAF, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EB0, 0x1EB0, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EB1, 0x1EB1, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EB2, 0x1EB2, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EB3, 0x1EB3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EB4, 0x1EB4, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EB5, 0x1EB5, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EB6, 0x1EB6, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EB7, 0x1EB7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EB8, 0x1EB8, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EB9, 0x1EB9, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EBA, 0x1EBA, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EBB, 0x1EBB, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EBC, 0x1EBC, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EBD, 0x1EBD, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EBE, 0x1EBE, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EBF, 0x1EBF, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EC0, 0x1EC0, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EC1, 0x1EC1, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EC2, 0x1EC2, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EC3, 0x1EC3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EC4, 0x1EC4, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EC5, 0x1EC5, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EC6, 0x1EC6, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EC7, 0x1EC7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EC8, 0x1EC8, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EC9, 0x1EC9, UNICODE_LOWERCASE_LETTER},
                                                            {0x1ECA, 0x1ECA, UNICODE_UPPERCASE_LETTER},
                                                            {0x1ECB, 0x1ECB, UNICODE_LOWERCASE_LETTER},
                                                            {0x1ECC, 0x1ECC, UNICODE_UPPERCASE_LETTER},
                                                            {0x1ECD, 0x1ECD, UNICODE_LOWERCASE_LETTER},
                                                            {0x1ECE, 0x1ECE, UNICODE_UPPERCASE_LETTER},
                                                            {0x1ECF, 0x1ECF, UNICODE_LOWERCASE_LETTER},
                                                            {0x1ED0, 0x1ED0, UNICODE_UPPERCASE_LETTER},
                                                            {0x1ED1, 0x1ED1, UNICODE_LOWERCASE_LETTER},
                                                            {0x1ED2, 0x1ED2, UNICODE_UPPERCASE_LETTER},
                                                            {0x1ED3, 0x1ED3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1ED4, 0x1ED4, UNICODE_UPPERCASE_LETTER},
                                                            {0x1ED5, 0x1ED5, UNICODE_LOWERCASE_LETTER},
                                                            {0x1ED6, 0x1ED6, UNICODE_UPPERCASE_LETTER},
                                                            {0x1ED7, 0x1ED7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1ED8, 0x1ED8, UNICODE_UPPERCASE_LETTER},
                                                            {0x1ED9, 0x1ED9, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EDA, 0x1EDA, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EDB, 0x1EDB, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EDC, 0x1EDC, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EDD, 0x1EDD, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EDE, 0x1EDE, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EDF, 0x1EDF, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EE0, 0x1EE0, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EE1, 0x1EE1, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EE2, 0x1EE2, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EE3, 0x1EE3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EE4, 0x1EE4, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EE5, 0x1EE5, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EE6, 0x1EE6, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EE7, 0x1EE7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EE8, 0x1EE8, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EE9, 0x1EE9, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EEA, 0x1EEA, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EEB, 0x1EEB, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EEC, 0x1EEC, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EED, 0x1EED, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EEE, 0x1EEE, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EEF, 0x1EEF, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EF0, 0x1EF0, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EF1, 0x1EF1, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EF2, 0x1EF2, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EF3, 0x1EF3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EF4, 0x1EF4, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EF5, 0x1EF5, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EF6, 0x1EF6, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EF7, 0x1EF7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1EF8, 0x1EF8, UNICODE_UPPERCASE_LETTER},
                                                            {0x1EF9, 0x1EF9, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F00, 0x1F07, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F08, 0x1F0F, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F10, 0x1F15, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F18, 0x1F1D, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F20, 0x1F27, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F28, 0x1F2F, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F30, 0x1F37, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F38, 0x1F3F, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F40, 0x1F45, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F48, 0x1F4D, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F50, 0x1F57, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F59, 0x1F59, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F5B, 0x1F5B, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F5D, 0x1F5D, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F5F, 0x1F5F, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F60, 0x1F67, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F68, 0x1F6F, UNICODE_UPPERCASE_LETTER},
                                                            {0x1F70, 0x1F7D, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F80, 0x1F87, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F88, 0x1F8F, UNICODE_TITLECASE_LETTER},
                                                            {0x1F90, 0x1F97, UNICODE_LOWERCASE_LETTER},
                                                            {0x1F98, 0x1F9F, UNICODE_TITLECASE_LETTER},
                                                            {0x1FA0, 0x1FA7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FA8, 0x1FAF, UNICODE_TITLECASE_LETTER},
                                                            {0x1FB0, 0x1FB4, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FB6, 0x1FB7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FB8, 0x1FBB, UNICODE_UPPERCASE_LETTER},
                                                            {0x1FBC, 0x1FBC, UNICODE_TITLECASE_LETTER},
                                                            {0x1FBD, 0x1FBD, UNICODE_MODIFIER_SYMBOL},
                                                            {0x1FBE, 0x1FBE, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FBF, 0x1FC1, UNICODE_MODIFIER_SYMBOL},
                                                            {0x1FC2, 0x1FC4, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FC6, 0x1FC7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FC8, 0x1FCB, UNICODE_UPPERCASE_LETTER},
                                                            {0x1FCC, 0x1FCC, UNICODE_TITLECASE_LETTER},
                                                            {0x1FCD, 0x1FCF, UNICODE_MODIFIER_SYMBOL},
                                                            {0x1FD0, 0x1FD3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FD6, 0x1FD7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FD8, 0x1FDB, UNICODE_UPPERCASE_LETTER},
                                                            {0x1FDD, 0x1FDF, UNICODE_MODIFIER_SYMBOL},
                                                            {0x1FE0, 0x1FE7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FE8, 0x1FEC, UNICODE_UPPERCASE_LETTER},
                                                            {0x1FED, 0x1FEF, UNICODE_MODIFIER_SYMBOL},
                                                            {0x1FF2, 0x1FF4, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FF6, 0x1FF7, UNICODE_LOWERCASE_LETTER},
                                                            {0x1FF8, 0x1FFB, UNICODE_UPPERCASE_LETTER},
                                                            {0x1FFC, 0x1FFC, UNICODE_TITLECASE_LETTER},
                                                            {0x1FFD, 0x1FFE, UNICODE_MODIFIER_SYMBOL},
                                                            {0x2000, 0x200A, UNICODE_SPACE_SEPARATOR},
                                                            {0x200B, 0x200F, UNICODE_FORMAT},
                                                            {0x2010, 0x2015, UNICODE_DASH_PUNCTUATION},
                                                            {0x2016, 0x2017, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2018, 0x2018, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x2019, 0x2019, UNICODE_FINAL_PUNCTUATION},
                                                            {0x201A, 0x201A, UNICODE_OPEN_PUNCTUATION},
                                                            {0x201B, 0x201C, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x201D, 0x201D, UNICODE_FINAL_PUNCTUATION},
                                                            {0x201E, 0x201E, UNICODE_OPEN_PUNCTUATION},
                                                            {0x201F, 0x201F, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x2020, 0x2027, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2028, 0x2028, UNICODE_LINE_SEPARATOR},
                                                            {0x2029, 0x2029, UNICODE_PARAGRAPH_SEPARATOR},
                                                            {0x202A, 0x202E, UNICODE_FORMAT},
                                                            {0x202F, 0x202F, UNICODE_SPACE_SEPARATOR},
                                                            {0x2030, 0x2038, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2039, 0x2039, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x203A, 0x203A, UNICODE_FINAL_PUNCTUATION},
                                                            {0x203B, 0x203E, UNICODE_OTHER_PUNCTUATION},
                                                            {0x203F, 0x2040, UNICODE_CONNECT_PUNCTUATION},
                                                            {0x2041, 0x2043, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2044, 0x2044, UNICODE_MATH_SYMBOL},
                                                            {0x2045, 0x2045, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2046, 0x2046, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2047, 0x2051, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2052, 0x2052, UNICODE_MATH_SYMBOL},
                                                            {0x2053, 0x2053, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2054, 0x2054, UNICODE_CONNECT_PUNCTUATION},
                                                            {0x2055, 0x205E, UNICODE_OTHER_PUNCTUATION},
                                                            {0x205F, 0x205F, UNICODE_SPACE_SEPARATOR},
                                                            {0x2060, 0x2063, UNICODE_FORMAT},
                                                            {0x206A, 0x206F, UNICODE_FORMAT},
                                                            {0x2070, 0x2070, UNICODE_OTHER_NUMBER},
                                                            {0x2071, 0x2071, UNICODE_LOWERCASE_LETTER},
                                                            {0x2074, 0x2079, UNICODE_OTHER_NUMBER},
                                                            {0x207A, 0x207C, UNICODE_MATH_SYMBOL},
                                                            {0x207D, 0x207D, UNICODE_OPEN_PUNCTUATION},
                                                            {0x207E, 0x207E, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x207F, 0x207F, UNICODE_LOWERCASE_LETTER},
                                                            {0x2080, 0x2089, UNICODE_OTHER_NUMBER},
                                                            {0x208A, 0x208C, UNICODE_MATH_SYMBOL},
                                                            {0x208D, 0x208D, UNICODE_OPEN_PUNCTUATION},
                                                            {0x208E, 0x208E, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2090, 0x2094, UNICODE_MODIFIER_LETTER},
                                                            {0x20A0, 0x20B5, UNICODE_CURRENCY_SYMBOL},
                                                            {0x20D0, 0x20DC, UNICODE_NON_SPACING_MARK},
                                                            {0x20DD, 0x20E0, UNICODE_ENCLOSING_MARK},
                                                            {0x20E1, 0x20E1, UNICODE_NON_SPACING_MARK},
                                                            {0x20E2, 0x20E4, UNICODE_ENCLOSING_MARK},
                                                            {0x20E5, 0x20EF, UNICODE_NON_SPACING_MARK},
                                                            {0x2100, 0x2101, UNICODE_OTHER_SYMBOL},
                                                            {0x2102, 0x2102, UNICODE_UPPERCASE_LETTER},
                                                            {0x2103, 0x2106, UNICODE_OTHER_SYMBOL},
                                                            {0x2107, 0x2107, UNICODE_UPPERCASE_LETTER},
                                                            {0x2108, 0x2109, UNICODE_OTHER_SYMBOL},
                                                            {0x210A, 0x210A, UNICODE_LOWERCASE_LETTER},
                                                            {0x210B, 0x210D, UNICODE_UPPERCASE_LETTER},
                                                            {0x210E, 0x210F, UNICODE_LOWERCASE_LETTER},
                                                            {0x2110, 0x2112, UNICODE_UPPERCASE_LETTER},
                                                            {0x2113, 0x2113, UNICODE_LOWERCASE_LETTER},
                                                            {0x2114, 0x2114, UNICODE_OTHER_SYMBOL},
                                                            {0x2115, 0x2115, UNICODE_UPPERCASE_LETTER},
                                                            {0x2116, 0x2118, UNICODE_OTHER_SYMBOL},
                                                            {0x2119, 0x211D, UNICODE_UPPERCASE_LETTER},
                                                            {0x211E, 0x2123, UNICODE_OTHER_SYMBOL},
                                                            {0x2124, 0x2124, UNICODE_UPPERCASE_LETTER},
                                                            {0x2125, 0x2125, UNICODE_OTHER_SYMBOL},
                                                            {0x2126, 0x2126, UNICODE_UPPERCASE_LETTER},
                                                            {0x2127, 0x2127, UNICODE_OTHER_SYMBOL},
                                                            {0x2128, 0x2128, UNICODE_UPPERCASE_LETTER},
                                                            {0x2129, 0x2129, UNICODE_OTHER_SYMBOL},
                                                            {0x212A, 0x212D, UNICODE_UPPERCASE_LETTER},
                                                            {0x212E, 0x212E, UNICODE_OTHER_SYMBOL},
                                                            {0x212F, 0x212F, UNICODE_LOWERCASE_LETTER},
                                                            {0x2130, 0x2133, UNICODE_UPPERCASE_LETTER},
                                                            {0x2134, 0x2134, UNICODE_LOWERCASE_LETTER},
                                                            {0x2135, 0x2138, UNICODE_OTHER_LETTER},
                                                            {0x2139, 0x2139, UNICODE_LOWERCASE_LETTER},
                                                            {0x213A, 0x213B, UNICODE_OTHER_SYMBOL},
                                                            {0x213C, 0x213D, UNICODE_LOWERCASE_LETTER},
                                                            {0x213E, 0x213F, UNICODE_UPPERCASE_LETTER},
                                                            {0x2140, 0x2144, UNICODE_MATH_SYMBOL},
                                                            {0x2145, 0x2145, UNICODE_UPPERCASE_LETTER},
                                                            {0x2146, 0x2149, UNICODE_LOWERCASE_LETTER},
                                                            {0x214A, 0x214A, UNICODE_OTHER_SYMBOL},
                                                            {0x214B, 0x214B, UNICODE_MATH_SYMBOL},
                                                            {0x214C, 0x214D, UNICODE_OTHER_SYMBOL},
                                                            {0x214E, 0x214E, UNICODE_LOWERCASE_LETTER},
                                                            {0x2153, 0x215F, UNICODE_OTHER_NUMBER},
                                                            {0x2160, 0x2182, UNICODE_LETTER_NUMBER},
                                                            {0x2183, 0x2183, UNICODE_UPPERCASE_LETTER},
                                                            {0x2184, 0x2184, UNICODE_LOWERCASE_LETTER},
                                                            {0x2190, 0x2194, UNICODE_MATH_SYMBOL},
                                                            {0x2195, 0x2199, UNICODE_OTHER_SYMBOL},
                                                            {0x219A, 0x219B, UNICODE_MATH_SYMBOL},
                                                            {0x219C, 0x219F, UNICODE_OTHER_SYMBOL},
                                                            {0x21A0, 0x21A0, UNICODE_MATH_SYMBOL},
                                                            {0x21A1, 0x21A2, UNICODE_OTHER_SYMBOL},
                                                            {0x21A3, 0x21A3, UNICODE_MATH_SYMBOL},
                                                            {0x21A4, 0x21A5, UNICODE_OTHER_SYMBOL},
                                                            {0x21A6, 0x21A6, UNICODE_MATH_SYMBOL},
                                                            {0x21A7, 0x21AD, UNICODE_OTHER_SYMBOL},
                                                            {0x21AE, 0x21AE, UNICODE_MATH_SYMBOL},
                                                            {0x21AF, 0x21CD, UNICODE_OTHER_SYMBOL},
                                                            {0x21CE, 0x21CF, UNICODE_MATH_SYMBOL},
                                                            {0x21D0, 0x21D1, UNICODE_OTHER_SYMBOL},
                                                            {0x21D2, 0x21D2, UNICODE_MATH_SYMBOL},
                                                            {0x21D3, 0x21D3, UNICODE_OTHER_SYMBOL},
                                                            {0x21D4, 0x21D4, UNICODE_MATH_SYMBOL},
                                                            {0x21D5, 0x21F3, UNICODE_OTHER_SYMBOL},
                                                            {0x21F4, 0x22FF, UNICODE_MATH_SYMBOL},
                                                            {0x2300, 0x2307, UNICODE_OTHER_SYMBOL},
                                                            {0x2308, 0x230B, UNICODE_MATH_SYMBOL},
                                                            {0x230C, 0x231F, UNICODE_OTHER_SYMBOL},
                                                            {0x2320, 0x2321, UNICODE_MATH_SYMBOL},
                                                            {0x2322, 0x2328, UNICODE_OTHER_SYMBOL},
                                                            {0x2329, 0x2329, UNICODE_OPEN_PUNCTUATION},
                                                            {0x232A, 0x232A, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x232B, 0x237B, UNICODE_OTHER_SYMBOL},
                                                            {0x237C, 0x237C, UNICODE_MATH_SYMBOL},
                                                            {0x237D, 0x239A, UNICODE_OTHER_SYMBOL},
                                                            {0x239B, 0x23B3, UNICODE_MATH_SYMBOL},
                                                            {0x23B4, 0x23DB, UNICODE_OTHER_SYMBOL},
                                                            {0x23DC, 0x23E1, UNICODE_MATH_SYMBOL},
                                                            {0x23E2, 0x23E7, UNICODE_OTHER_SYMBOL},
                                                            {0x2400, 0x2426, UNICODE_OTHER_SYMBOL},
                                                            {0x2440, 0x244A, UNICODE_OTHER_SYMBOL},
                                                            {0x2460, 0x249B, UNICODE_OTHER_NUMBER},
                                                            {0x249C, 0x24E9, UNICODE_OTHER_SYMBOL},
                                                            {0x24EA, 0x24FF, UNICODE_OTHER_NUMBER},
                                                            {0x2500, 0x25B6, UNICODE_OTHER_SYMBOL},
                                                            {0x25B7, 0x25B7, UNICODE_MATH_SYMBOL},
                                                            {0x25B8, 0x25C0, UNICODE_OTHER_SYMBOL},
                                                            {0x25C1, 0x25C1, UNICODE_MATH_SYMBOL},
                                                            {0x25C2, 0x25F7, UNICODE_OTHER_SYMBOL},
                                                            {0x25F8, 0x25FF, UNICODE_MATH_SYMBOL},
                                                            {0x2600, 0x266E, UNICODE_OTHER_SYMBOL},
                                                            {0x266F, 0x266F, UNICODE_MATH_SYMBOL},
                                                            {0x2670, 0x269C, UNICODE_OTHER_SYMBOL},
                                                            {0x26A0, 0x26B2, UNICODE_OTHER_SYMBOL},
                                                            {0x2701, 0x2704, UNICODE_OTHER_SYMBOL},
                                                            {0x2706, 0x2709, UNICODE_OTHER_SYMBOL},
                                                            {0x270C, 0x2727, UNICODE_OTHER_SYMBOL},
                                                            {0x2729, 0x274B, UNICODE_OTHER_SYMBOL},
                                                            {0x274D, 0x274D, UNICODE_OTHER_SYMBOL},
                                                            {0x274F, 0x2752, UNICODE_OTHER_SYMBOL},
                                                            {0x2756, 0x2756, UNICODE_OTHER_SYMBOL},
                                                            {0x2758, 0x275E, UNICODE_OTHER_SYMBOL},
                                                            {0x2761, 0x2767, UNICODE_OTHER_SYMBOL},
                                                            {0x2768, 0x2768, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2769, 0x2769, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x276A, 0x276A, UNICODE_OPEN_PUNCTUATION},
                                                            {0x276B, 0x276B, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x276C, 0x276C, UNICODE_OPEN_PUNCTUATION},
                                                            {0x276D, 0x276D, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x276E, 0x276E, UNICODE_OPEN_PUNCTUATION},
                                                            {0x276F, 0x276F, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2770, 0x2770, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2771, 0x2771, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2772, 0x2772, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2773, 0x2773, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2774, 0x2774, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2775, 0x2775, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2776, 0x2793, UNICODE_OTHER_NUMBER},
                                                            {0x2794, 0x2794, UNICODE_OTHER_SYMBOL},
                                                            {0x2798, 0x27AF, UNICODE_OTHER_SYMBOL},
                                                            {0x27B1, 0x27BE, UNICODE_OTHER_SYMBOL},
                                                            {0x27C0, 0x27C4, UNICODE_MATH_SYMBOL},
                                                            {0x27C5, 0x27C5, UNICODE_OPEN_PUNCTUATION},
                                                            {0x27C6, 0x27C6, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x27C7, 0x27CA, UNICODE_MATH_SYMBOL},
                                                            {0x27D0, 0x27E5, UNICODE_MATH_SYMBOL},
                                                            {0x27E6, 0x27E6, UNICODE_OPEN_PUNCTUATION},
                                                            {0x27E7, 0x27E7, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x27E8, 0x27E8, UNICODE_OPEN_PUNCTUATION},
                                                            {0x27E9, 0x27E9, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x27EA, 0x27EA, UNICODE_OPEN_PUNCTUATION},
                                                            {0x27EB, 0x27EB, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x27F0, 0x27FF, UNICODE_MATH_SYMBOL},
                                                            {0x2800, 0x28FF, UNICODE_OTHER_SYMBOL},
                                                            {0x2900, 0x2982, UNICODE_MATH_SYMBOL},
                                                            {0x2983, 0x2983, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2984, 0x2984, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2985, 0x2985, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2986, 0x2986, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2987, 0x2987, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2988, 0x2988, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2989, 0x2989, UNICODE_OPEN_PUNCTUATION},
                                                            {0x298A, 0x298A, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x298B, 0x298B, UNICODE_OPEN_PUNCTUATION},
                                                            {0x298C, 0x298C, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x298D, 0x298D, UNICODE_OPEN_PUNCTUATION},
                                                            {0x298E, 0x298E, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x298F, 0x298F, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2990, 0x2990, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2991, 0x2991, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2992, 0x2992, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2993, 0x2993, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2994, 0x2994, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2995, 0x2995, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2996, 0x2996, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2997, 0x2997, UNICODE_OPEN_PUNCTUATION},
                                                            {0x2998, 0x2998, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x2999, 0x29D7, UNICODE_MATH_SYMBOL},
                                                            {0x29D8, 0x29D8, UNICODE_OPEN_PUNCTUATION},
                                                            {0x29D9, 0x29D9, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x29DA, 0x29DA, UNICODE_OPEN_PUNCTUATION},
                                                            {0x29DB, 0x29DB, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x29DC, 0x29FB, UNICODE_MATH_SYMBOL},
                                                            {0x29FC, 0x29FC, UNICODE_OPEN_PUNCTUATION},
                                                            {0x29FD, 0x29FD, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x29FE, 0x2AFF, UNICODE_MATH_SYMBOL},
                                                            {0x2B00, 0x2B1A, UNICODE_OTHER_SYMBOL},
                                                            {0x2B20, 0x2B23, UNICODE_OTHER_SYMBOL},
                                                            {0x2C00, 0x2C2E, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C30, 0x2C5E, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C60, 0x2C60, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C61, 0x2C61, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C62, 0x2C64, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C65, 0x2C66, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C67, 0x2C67, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C68, 0x2C68, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C69, 0x2C69, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C6A, 0x2C6A, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C6B, 0x2C6B, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C6C, 0x2C6C, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C74, 0x2C74, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C75, 0x2C75, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C76, 0x2C77, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C80, 0x2C80, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C81, 0x2C81, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C82, 0x2C82, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C83, 0x2C83, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C84, 0x2C84, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C85, 0x2C85, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C86, 0x2C86, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C87, 0x2C87, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C88, 0x2C88, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C89, 0x2C89, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C8A, 0x2C8A, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C8B, 0x2C8B, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C8C, 0x2C8C, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C8D, 0x2C8D, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C8E, 0x2C8E, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C8F, 0x2C8F, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C90, 0x2C90, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C91, 0x2C91, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C92, 0x2C92, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C93, 0x2C93, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C94, 0x2C94, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C95, 0x2C95, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C96, 0x2C96, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C97, 0x2C97, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C98, 0x2C98, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C99, 0x2C99, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C9A, 0x2C9A, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C9B, 0x2C9B, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C9C, 0x2C9C, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C9D, 0x2C9D, UNICODE_LOWERCASE_LETTER},
                                                            {0x2C9E, 0x2C9E, UNICODE_UPPERCASE_LETTER},
                                                            {0x2C9F, 0x2C9F, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CA0, 0x2CA0, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CA1, 0x2CA1, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CA2, 0x2CA2, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CA3, 0x2CA3, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CA4, 0x2CA4, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CA5, 0x2CA5, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CA6, 0x2CA6, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CA7, 0x2CA7, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CA8, 0x2CA8, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CA9, 0x2CA9, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CAA, 0x2CAA, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CAB, 0x2CAB, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CAC, 0x2CAC, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CAD, 0x2CAD, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CAE, 0x2CAE, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CAF, 0x2CAF, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CB0, 0x2CB0, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CB1, 0x2CB1, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CB2, 0x2CB2, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CB3, 0x2CB3, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CB4, 0x2CB4, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CB5, 0x2CB5, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CB6, 0x2CB6, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CB7, 0x2CB7, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CB8, 0x2CB8, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CB9, 0x2CB9, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CBA, 0x2CBA, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CBB, 0x2CBB, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CBC, 0x2CBC, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CBD, 0x2CBD, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CBE, 0x2CBE, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CBF, 0x2CBF, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CC0, 0x2CC0, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CC1, 0x2CC1, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CC2, 0x2CC2, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CC3, 0x2CC3, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CC4, 0x2CC4, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CC5, 0x2CC5, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CC6, 0x2CC6, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CC7, 0x2CC7, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CC8, 0x2CC8, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CC9, 0x2CC9, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CCA, 0x2CCA, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CCB, 0x2CCB, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CCC, 0x2CCC, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CCD, 0x2CCD, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CCE, 0x2CCE, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CCF, 0x2CCF, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CD0, 0x2CD0, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CD1, 0x2CD1, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CD2, 0x2CD2, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CD3, 0x2CD3, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CD4, 0x2CD4, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CD5, 0x2CD5, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CD6, 0x2CD6, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CD7, 0x2CD7, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CD8, 0x2CD8, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CD9, 0x2CD9, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CDA, 0x2CDA, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CDB, 0x2CDB, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CDC, 0x2CDC, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CDD, 0x2CDD, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CDE, 0x2CDE, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CDF, 0x2CDF, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CE0, 0x2CE0, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CE1, 0x2CE1, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CE2, 0x2CE2, UNICODE_UPPERCASE_LETTER},
                                                            {0x2CE3, 0x2CE4, UNICODE_LOWERCASE_LETTER},
                                                            {0x2CE5, 0x2CEA, UNICODE_OTHER_SYMBOL},
                                                            {0x2CF9, 0x2CFC, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2CFD, 0x2CFD, UNICODE_OTHER_NUMBER},
                                                            {0x2CFE, 0x2CFF, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2D00, 0x2D25, UNICODE_LOWERCASE_LETTER},
                                                            {0x2D30, 0x2D65, UNICODE_OTHER_LETTER},
                                                            {0x2D6F, 0x2D6F, UNICODE_MODIFIER_LETTER},
                                                            {0x2D80, 0x2D96, UNICODE_OTHER_LETTER},
                                                            {0x2DA0, 0x2DA6, UNICODE_OTHER_LETTER},
                                                            {0x2DA8, 0x2DAE, UNICODE_OTHER_LETTER},
                                                            {0x2DB0, 0x2DB6, UNICODE_OTHER_LETTER},
                                                            {0x2DB8, 0x2DBE, UNICODE_OTHER_LETTER},
                                                            {0x2DC0, 0x2DC6, UNICODE_OTHER_LETTER},
                                                            {0x2DC8, 0x2DCE, UNICODE_OTHER_LETTER},
                                                            {0x2DD0, 0x2DD6, UNICODE_OTHER_LETTER},
                                                            {0x2DD8, 0x2DDE, UNICODE_OTHER_LETTER},
                                                            {0x2E00, 0x2E01, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2E02, 0x2E02, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x2E03, 0x2E03, UNICODE_FINAL_PUNCTUATION},
                                                            {0x2E04, 0x2E04, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x2E05, 0x2E05, UNICODE_FINAL_PUNCTUATION},
                                                            {0x2E06, 0x2E08, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2E09, 0x2E09, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x2E0A, 0x2E0A, UNICODE_FINAL_PUNCTUATION},
                                                            {0x2E0B, 0x2E0B, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2E0C, 0x2E0C, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x2E0D, 0x2E0D, UNICODE_FINAL_PUNCTUATION},
                                                            {0x2E0E, 0x2E16, UNICODE_OTHER_PUNCTUATION},
                                                            {0x2E17, 0x2E17, UNICODE_DASH_PUNCTUATION},
                                                            {0x2E1C, 0x2E1C, UNICODE_INITIAL_PUNCTUATION},
                                                            {0x2E1D, 0x2E1D, UNICODE_FINAL_PUNCTUATION},
                                                            {0x2E80, 0x2E99, UNICODE_OTHER_SYMBOL},
                                                            {0x2E9B, 0x2EF3, UNICODE_OTHER_SYMBOL},
                                                            {0x2F00, 0x2FD5, UNICODE_OTHER_SYMBOL},
                                                            {0x2FF0, 0x2FFB, UNICODE_OTHER_SYMBOL},
                                                            {0x3000, 0x3000, UNICODE_SPACE_SEPARATOR},
                                                            {0x3001, 0x3003, UNICODE_OTHER_PUNCTUATION},
                                                            {0x3004, 0x3004, UNICODE_OTHER_SYMBOL},
                                                            {0x3005, 0x3005, UNICODE_MODIFIER_LETTER},
                                                            {0x3006, 0x3006, UNICODE_OTHER_LETTER},
                                                            {0x3007, 0x3007, UNICODE_LETTER_NUMBER},
                                                            {0x3008, 0x3008, UNICODE_OPEN_PUNCTUATION},
                                                            {0x3009, 0x3009, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x300A, 0x300A, UNICODE_OPEN_PUNCTUATION},
                                                            {0x300B, 0x300B, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x300C, 0x300C, UNICODE_OPEN_PUNCTUATION},
                                                            {0x300D, 0x300D, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x300E, 0x300E, UNICODE_OPEN_PUNCTUATION},
                                                            {0x300F, 0x300F, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x3010, 0x3010, UNICODE_OPEN_PUNCTUATION},
                                                            {0x3011, 0x3011, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x3012, 0x3013, UNICODE_OTHER_SYMBOL},
                                                            {0x3014, 0x3014, UNICODE_OPEN_PUNCTUATION},
                                                            {0x3015, 0x3015, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x3016, 0x3016, UNICODE_OPEN_PUNCTUATION},
                                                            {0x3017, 0x3017, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x3018, 0x3018, UNICODE_OPEN_PUNCTUATION},
                                                            {0x3019, 0x3019, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x301A, 0x301A, UNICODE_OPEN_PUNCTUATION},
                                                            {0x301B, 0x301B, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x301C, 0x301C, UNICODE_DASH_PUNCTUATION},
                                                            {0x301D, 0x301D, UNICODE_OPEN_PUNCTUATION},
                                                            {0x301E, 0x301F, UNICODE_CLOSE_PUNCTUATION},
                                                            {0x3020, 0x3020, UNICODE_OTHER_SYMBOL},
                                                            {0x3021, 0x3029, UNICODE_LETTER_NUMBER},
                                                            {0x302A, 0x302F, UNICODE_NON_SPACING_MARK},
                                                            {0x3030, 0x3030, UNICODE_DASH_PUNCTUATION},
                                                            {0x3031, 0x3035, UNICODE_MODIFIER_LETTER},
                                                            {0x3036, 0x3037, UNICODE_OTHER_SYMBOL},
                                                            {0x3038, 0x303A, UNICODE_LETTER_NUMBER},
                                                            {0x303B, 0x303B, UNICODE_MODIFIER_LETTER},
                                                            {0x303C, 0x303C, UNICODE_OTHER_LETTER},
                                                            {0x303D, 0x303D, UNICODE_OTHER_PUNCTUATION},
                                                            {0x303E, 0x303F, UNICODE_OTHER_SYMBOL},
                                                            {0x3041, 0x3096, UNICODE_OTHER_LETTER},
                                                            {0x3099, 0x309A, UNICODE_NON_SPACING_MARK},
                                                            {0x309B, 0x309C, UNICODE_MODIFIER_SYMBOL},
                                                            {0x309D, 0x309E, UNICODE_MODIFIER_LETTER},
                                                            {0x309F, 0x309F, UNICODE_OTHER_LETTER},
                                                            {0x30A0, 0x30A0, UNICODE_DASH_PUNCTUATION},
                                                            {0x30A1, 0x30FA, UNICODE_OTHER_LETTER},
                                                            {0x30FB, 0x30FB, UNICODE_OTHER_PUNCTUATION},
                                                            {0x30FC, 0x30FE, UNICODE_MODIFIER_LETTER},
                                                            {0x30FF, 0x30FF, UNICODE_OTHER_LETTER},
                                                            {0x3105, 0x312C, UNICODE_OTHER_LETTER},
                                                            {0x3131, 0x318E, UNICODE_OTHER_LETTER},
                                                            {0x3190, 0x3191, UNICODE_OTHER_SYMBOL},
                                                            {0x3192, 0x3195, UNICODE_OTHER_NUMBER},
                                                            {0x3196, 0x319F, UNICODE_OTHER_SYMBOL},
                                                            {0x31A0, 0x31B7, UNICODE_OTHER_LETTER},
                                                            {0x31C0, 0x31CF, UNICODE_OTHER_SYMBOL},
                                                            {0x31F0, 0x31FF, UNICODE_OTHER_LETTER},
                                                            {0x3200, 0x321E, UNICODE_OTHER_SYMBOL},
                                                            {0x3220, 0x3229, UNICODE_OTHER_NUMBER},
                                                            {0x322A, 0x3243, UNICODE_OTHER_SYMBOL},
                                                            {0x3250, 0x3250, UNICODE_OTHER_SYMBOL},
                                                            {0x3251, 0x325F, UNICODE_OTHER_NUMBER},
                                                            {0x3260, 0x327F, UNICODE_OTHER_SYMBOL},
                                                            {0x3280, 0x3289, UNICODE_OTHER_NUMBER},
                                                            {0x328A, 0x32B0, UNICODE_OTHER_SYMBOL},
                                                            {0x32B1, 0x32BF, UNICODE_OTHER_NUMBER},
                                                            {0x32C0, 0x32FE, UNICODE_OTHER_SYMBOL},
                                                            {0x3300, 0x33FF, UNICODE_OTHER_SYMBOL},
                                                            {0x3400, 0x4DB5, UNICODE_OTHER_LETTER},
                                                            {0x4DC0, 0x4DFF, UNICODE_OTHER_SYMBOL},
                                                            {0x4E00, 0x9FBB, UNICODE_OTHER_LETTER},
                                                            {0xA000, 0xA014, UNICODE_OTHER_LETTER},
                                                            {0xA015, 0xA015, UNICODE_MODIFIER_LETTER},
                                                            {0xA016, 0xA48C, UNICODE_OTHER_LETTER},
                                                            {0xA490, 0xA4C6, UNICODE_OTHER_SYMBOL},
                                                            {0xA700, 0xA716, UNICODE_MODIFIER_SYMBOL},
                                                            {0xA717, 0xA71A, UNICODE_MODIFIER_LETTER},
                                                            {0xA720, 0xA721, UNICODE_MODIFIER_SYMBOL},
                                                            {0xA800, 0xA801, UNICODE_OTHER_LETTER},
                                                            {0xA802, 0xA802, UNICODE_COMBINING_MARK},
                                                            {0xA803, 0xA805, UNICODE_OTHER_LETTER},
                                                            {0xA806, 0xA806, UNICODE_NON_SPACING_MARK},
                                                            {0xA807, 0xA80A, UNICODE_OTHER_LETTER},
                                                            {0xA80B, 0xA80B, UNICODE_NON_SPACING_MARK},
                                                            {0xA80C, 0xA822, UNICODE_OTHER_LETTER},
                                                            {0xA823, 0xA824, UNICODE_COMBINING_MARK},
                                                            {0xA825, 0xA826, UNICODE_NON_SPACING_MARK},
                                                            {0xA827, 0xA827, UNICODE_COMBINING_MARK},
                                                            {0xA828, 0xA82B, UNICODE_OTHER_SYMBOL},
                                                            {0xA840, 0xA873, UNICODE_OTHER_LETTER},
                                                            {0xA874, 0xA877, UNICODE_OTHER_PUNCTUATION},
                                                            {0xAC00, 0xD7A3, UNICODE_OTHER_LETTER},
                                                            {0xD800, 0xDB7F, UNICODE_SURROGATE},
                                                            {0xDB80, 0xDBFF, UNICODE_SURROGATE},
                                                            {0xDC00, 0xDFFF, UNICODE_SURROGATE},
                                                            {0xE000, 0xF8FF, UNICODE_PRIVATE_USE},
                                                            {0xF900, 0xFA2D, UNICODE_OTHER_LETTER},
                                                            {0xFA30, 0xFA6A, UNICODE_OTHER_LETTER},
                                                            {0xFA70, 0xFAD9, UNICODE_OTHER_LETTER},
                                                            {0xFB00, 0xFB06, UNICODE_LOWERCASE_LETTER},
                                                            {0xFB13, 0xFB17, UNICODE_LOWERCASE_LETTER},
                                                            {0xFB1D, 0xFB1D, UNICODE_OTHER_LETTER},
                                                            {0xFB1E, 0xFB1E, UNICODE_NON_SPACING_MARK},
                                                            {0xFB1F, 0xFB28, UNICODE_OTHER_LETTER},
                                                            {0xFB29, 0xFB29, UNICODE_MATH_SYMBOL},
                                                            {0xFB2A, 0xFB36, UNICODE_OTHER_LETTER},
                                                            {0xFB38, 0xFB3C, UNICODE_OTHER_LETTER},
                                                            {0xFB3E, 0xFB3E, UNICODE_OTHER_LETTER},
                                                            {0xFB40, 0xFB41, UNICODE_OTHER_LETTER},
                                                            {0xFB43, 0xFB44, UNICODE_OTHER_LETTER},
                                                            {0xFB46, 0xFBB1, UNICODE_OTHER_LETTER},
                                                            {0xFBD3, 0xFD3D, UNICODE_OTHER_LETTER},
                                                            {0xFD3E, 0xFD3E, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFD3F, 0xFD3F, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFD50, 0xFD8F, UNICODE_OTHER_LETTER},
                                                            {0xFD92, 0xFDC7, UNICODE_OTHER_LETTER},
                                                            {0xFDF0, 0xFDFB, UNICODE_OTHER_LETTER},
                                                            {0xFDFC, 0xFDFC, UNICODE_CURRENCY_SYMBOL},
                                                            {0xFDFD, 0xFDFD, UNICODE_OTHER_SYMBOL},
                                                            {0xFE00, 0xFE0F, UNICODE_NON_SPACING_MARK},
                                                            {0xFE10, 0xFE16, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE17, 0xFE17, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE18, 0xFE18, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE19, 0xFE19, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE20, 0xFE23, UNICODE_NON_SPACING_MARK},
                                                            {0xFE30, 0xFE30, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE31, 0xFE32, UNICODE_DASH_PUNCTUATION},
                                                            {0xFE33, 0xFE34, UNICODE_CONNECT_PUNCTUATION},
                                                            {0xFE35, 0xFE35, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE36, 0xFE36, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE37, 0xFE37, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE38, 0xFE38, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE39, 0xFE39, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE3A, 0xFE3A, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE3B, 0xFE3B, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE3C, 0xFE3C, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE3D, 0xFE3D, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE3E, 0xFE3E, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE3F, 0xFE3F, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE40, 0xFE40, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE41, 0xFE41, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE42, 0xFE42, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE43, 0xFE43, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE44, 0xFE44, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE45, 0xFE46, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE47, 0xFE47, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE48, 0xFE48, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE49, 0xFE4C, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE4D, 0xFE4F, UNICODE_CONNECT_PUNCTUATION},
                                                            {0xFE50, 0xFE52, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE54, 0xFE57, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE58, 0xFE58, UNICODE_DASH_PUNCTUATION},
                                                            {0xFE59, 0xFE59, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE5A, 0xFE5A, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE5B, 0xFE5B, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE5C, 0xFE5C, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE5D, 0xFE5D, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFE5E, 0xFE5E, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFE5F, 0xFE61, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE62, 0xFE62, UNICODE_MATH_SYMBOL},
                                                            {0xFE63, 0xFE63, UNICODE_DASH_PUNCTUATION},
                                                            {0xFE64, 0xFE66, UNICODE_MATH_SYMBOL},
                                                            {0xFE68, 0xFE68, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE69, 0xFE69, UNICODE_CURRENCY_SYMBOL},
                                                            {0xFE6A, 0xFE6B, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFE70, 0xFE74, UNICODE_OTHER_LETTER},
                                                            {0xFE76, 0xFEFC, UNICODE_OTHER_LETTER},
                                                            {0xFEFF, 0xFEFF, UNICODE_FORMAT},
                                                            {0xFF01, 0xFF03, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF04, 0xFF04, UNICODE_CURRENCY_SYMBOL},
                                                            {0xFF05, 0xFF07, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF08, 0xFF08, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFF09, 0xFF09, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFF0A, 0xFF0A, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF0B, 0xFF0B, UNICODE_MATH_SYMBOL},
                                                            {0xFF0C, 0xFF0C, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF0D, 0xFF0D, UNICODE_DASH_PUNCTUATION},
                                                            {0xFF0E, 0xFF0F, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF10, 0xFF19, UNICODE_DECIMAL_NUMBER},
                                                            {0xFF1A, 0xFF1B, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF1C, 0xFF1E, UNICODE_MATH_SYMBOL},
                                                            {0xFF1F, 0xFF20, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF21, 0xFF3A, UNICODE_UPPERCASE_LETTER},
                                                            {0xFF3B, 0xFF3B, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFF3C, 0xFF3C, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF3D, 0xFF3D, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFF3E, 0xFF3E, UNICODE_MODIFIER_SYMBOL},
                                                            {0xFF3F, 0xFF3F, UNICODE_CONNECT_PUNCTUATION},
                                                            {0xFF40, 0xFF40, UNICODE_MODIFIER_SYMBOL},
                                                            {0xFF41, 0xFF5A, UNICODE_LOWERCASE_LETTER},
                                                            {0xFF5B, 0xFF5B, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFF5C, 0xFF5C, UNICODE_MATH_SYMBOL},
                                                            {0xFF5D, 0xFF5D, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFF5E, 0xFF5E, UNICODE_MATH_SYMBOL},
                                                            {0xFF5F, 0xFF5F, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFF60, 0xFF60, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFF61, 0xFF61, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF62, 0xFF62, UNICODE_OPEN_PUNCTUATION},
                                                            {0xFF63, 0xFF63, UNICODE_CLOSE_PUNCTUATION},
                                                            {0xFF64, 0xFF65, UNICODE_OTHER_PUNCTUATION},
                                                            {0xFF66, 0xFF6F, UNICODE_OTHER_LETTER},
                                                            {0xFF70, 0xFF70, UNICODE_MODIFIER_LETTER},
                                                            {0xFF71, 0xFF9D, UNICODE_OTHER_LETTER},
                                                            {0xFF9E, 0xFF9F, UNICODE_MODIFIER_LETTER},
                                                            {0xFFA0, 0xFFBE, UNICODE_OTHER_LETTER},
                                                            {0xFFC2, 0xFFC7, UNICODE_OTHER_LETTER},
                                                            {0xFFCA, 0xFFCF, UNICODE_OTHER_LETTER},
                                                            {0xFFD2, 0xFFD7, UNICODE_OTHER_LETTER},
                                                            {0xFFDA, 0xFFDC, UNICODE_OTHER_LETTER},
                                                            {0xFFE0, 0xFFE1, UNICODE_CURRENCY_SYMBOL},
                                                            {0xFFE2, 0xFFE2, UNICODE_MATH_SYMBOL},
                                                            {0xFFE3, 0xFFE3, UNICODE_MODIFIER_SYMBOL},
                                                            {0xFFE4, 0xFFE4, UNICODE_OTHER_SYMBOL},
                                                            {0xFFE5, 0xFFE6, UNICODE_CURRENCY_SYMBOL},
                                                            {0xFFE8, 0xFFE8, UNICODE_OTHER_SYMBOL},
                                                            {0xFFE9, 0xFFEC, UNICODE_MATH_SYMBOL},
                                                            {0xFFED, 0xFFEE, UNICODE_OTHER_SYMBOL},
                                                            {0xFFF9, 0xFFFB, UNICODE_FORMAT},
                                                            {0xFFFC, 0xFFFD, UNICODE_OTHER_SYMBOL},
                                                            {0x10000, 0x1000B, UNICODE_OTHER_LETTER},
                                                            {0x1000D, 0x10026, UNICODE_OTHER_LETTER},
                                                            {0x10028, 0x1003A, UNICODE_OTHER_LETTER},
                                                            {0x1003C, 0x1003D, UNICODE_OTHER_LETTER},
                                                            {0x1003F, 0x1004D, UNICODE_OTHER_LETTER},
                                                            {0x10050, 0x1005D, UNICODE_OTHER_LETTER},
                                                            {0x10080, 0x100FA, UNICODE_OTHER_LETTER},
                                                            {0x10100, 0x10101, UNICODE_OTHER_PUNCTUATION},
                                                            {0x10102, 0x10102, UNICODE_OTHER_SYMBOL},
                                                            {0x10107, 0x10133, UNICODE_OTHER_NUMBER},
                                                            {0x10137, 0x1013F, UNICODE_OTHER_SYMBOL},
                                                            {0x10140, 0x10174, UNICODE_LETTER_NUMBER},
                                                            {0x10175, 0x10178, UNICODE_OTHER_NUMBER},
                                                            {0x10179, 0x10189, UNICODE_OTHER_SYMBOL},
                                                            {0x1018A, 0x1018A, UNICODE_OTHER_NUMBER},
                                                            {0x10300, 0x1031E, UNICODE_OTHER_LETTER},
                                                            {0x10320, 0x10323, UNICODE_OTHER_NUMBER},
                                                            {0x10330, 0x10340, UNICODE_OTHER_LETTER},
                                                            {0x10341, 0x10341, UNICODE_LETTER_NUMBER},
                                                            {0x10342, 0x10349, UNICODE_OTHER_LETTER},
                                                            {0x1034A, 0x1034A, UNICODE_LETTER_NUMBER},
                                                            {0x10380, 0x1039D, UNICODE_OTHER_LETTER},
                                                            {0x1039F, 0x1039F, UNICODE_OTHER_PUNCTUATION},
                                                            {0x103A0, 0x103C3, UNICODE_OTHER_LETTER},
                                                            {0x103C8, 0x103CF, UNICODE_OTHER_LETTER},
                                                            {0x103D0, 0x103D0, UNICODE_OTHER_PUNCTUATION},
                                                            {0x103D1, 0x103D5, UNICODE_LETTER_NUMBER},
                                                            {0x10400, 0x10427, UNICODE_UPPERCASE_LETTER},
                                                            {0x10428, 0x1044F, UNICODE_LOWERCASE_LETTER},
                                                            {0x10450, 0x1049D, UNICODE_OTHER_LETTER},
                                                            {0x104A0, 0x104A9, UNICODE_DECIMAL_NUMBER},
                                                            {0x10800, 0x10805, UNICODE_OTHER_LETTER},
                                                            {0x10808, 0x10808, UNICODE_OTHER_LETTER},
                                                            {0x1080A, 0x10835, UNICODE_OTHER_LETTER},
                                                            {0x10837, 0x10838, UNICODE_OTHER_LETTER},
                                                            {0x1083C, 0x1083C, UNICODE_OTHER_LETTER},
                                                            {0x1083F, 0x1083F, UNICODE_OTHER_LETTER},
                                                            {0x10900, 0x10915, UNICODE_OTHER_LETTER},
                                                            {0x10916, 0x10919, UNICODE_OTHER_NUMBER},
                                                            {0x1091F, 0x1091F, UNICODE_OTHER_PUNCTUATION},
                                                            {0x10A00, 0x10A00, UNICODE_OTHER_LETTER},
                                                            {0x10A01, 0x10A03, UNICODE_NON_SPACING_MARK},
                                                            {0x10A05, 0x10A06, UNICODE_NON_SPACING_MARK},
                                                            {0x10A0C, 0x10A0F, UNICODE_NON_SPACING_MARK},
                                                            {0x10A10, 0x10A13, UNICODE_OTHER_LETTER},
                                                            {0x10A15, 0x10A17, UNICODE_OTHER_LETTER},
                                                            {0x10A19, 0x10A33, UNICODE_OTHER_LETTER},
                                                            {0x10A38, 0x10A3A, UNICODE_NON_SPACING_MARK},
                                                            {0x10A3F, 0x10A3F, UNICODE_NON_SPACING_MARK},
                                                            {0x10A40, 0x10A47, UNICODE_OTHER_NUMBER},
                                                            {0x10A50, 0x10A58, UNICODE_OTHER_PUNCTUATION},
                                                            {0x12000, 0x1236E, UNICODE_OTHER_LETTER},
                                                            {0x12400, 0x12462, UNICODE_LETTER_NUMBER},
                                                            {0x12470, 0x12473, UNICODE_OTHER_PUNCTUATION},
                                                            {0x1D000, 0x1D0F5, UNICODE_OTHER_SYMBOL},
                                                            {0x1D100, 0x1D126, UNICODE_OTHER_SYMBOL},
                                                            {0x1D12A, 0x1D164, UNICODE_OTHER_SYMBOL},
                                                            {0x1D165, 0x1D166, UNICODE_COMBINING_MARK},
                                                            {0x1D167, 0x1D169, UNICODE_NON_SPACING_MARK},
                                                            {0x1D16A, 0x1D16C, UNICODE_OTHER_SYMBOL},
                                                            {0x1D16D, 0x1D172, UNICODE_COMBINING_MARK},
                                                            {0x1D173, 0x1D17A, UNICODE_FORMAT},
                                                            {0x1D17B, 0x1D182, UNICODE_NON_SPACING_MARK},
                                                            {0x1D183, 0x1D184, UNICODE_OTHER_SYMBOL},
                                                            {0x1D185, 0x1D18B, UNICODE_NON_SPACING_MARK},
                                                            {0x1D18C, 0x1D1A9, UNICODE_OTHER_SYMBOL},
                                                            {0x1D1AA, 0x1D1AD, UNICODE_NON_SPACING_MARK},
                                                            {0x1D1AE, 0x1D1DD, UNICODE_OTHER_SYMBOL},
                                                            {0x1D200, 0x1D241, UNICODE_OTHER_SYMBOL},
                                                            {0x1D242, 0x1D244, UNICODE_NON_SPACING_MARK},
                                                            {0x1D245, 0x1D245, UNICODE_OTHER_SYMBOL},
                                                            {0x1D300, 0x1D356, UNICODE_OTHER_SYMBOL},
                                                            {0x1D360, 0x1D371, UNICODE_OTHER_NUMBER},
                                                            {0x1D400, 0x1D419, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D41A, 0x1D433, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D434, 0x1D44D, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D44E, 0x1D454, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D456, 0x1D467, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D468, 0x1D481, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D482, 0x1D49B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D49C, 0x1D49C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D49E, 0x1D49F, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D4A2, 0x1D4A2, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D4A5, 0x1D4A6, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D4A9, 0x1D4AC, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D4AE, 0x1D4B5, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D4B6, 0x1D4B9, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D4BB, 0x1D4BB, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D4BD, 0x1D4C3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D4C5, 0x1D4CF, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D4D0, 0x1D4E9, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D4EA, 0x1D503, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D504, 0x1D505, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D507, 0x1D50A, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D50D, 0x1D514, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D516, 0x1D51C, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D51E, 0x1D537, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D538, 0x1D539, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D53B, 0x1D53E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D540, 0x1D544, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D546, 0x1D546, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D54A, 0x1D550, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D552, 0x1D56B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D56C, 0x1D585, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D586, 0x1D59F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D5A0, 0x1D5B9, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D5BA, 0x1D5D3, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D5D4, 0x1D5ED, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D5EE, 0x1D607, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D608, 0x1D621, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D622, 0x1D63B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D63C, 0x1D655, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D656, 0x1D66F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D670, 0x1D689, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D68A, 0x1D6A5, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D6A8, 0x1D6C0, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D6C1, 0x1D6C1, UNICODE_MATH_SYMBOL},
                                                            {0x1D6C2, 0x1D6DA, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D6DB, 0x1D6DB, UNICODE_MATH_SYMBOL},
                                                            {0x1D6DC, 0x1D6E1, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D6E2, 0x1D6FA, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D6FB, 0x1D6FB, UNICODE_MATH_SYMBOL},
                                                            {0x1D6FC, 0x1D714, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D715, 0x1D715, UNICODE_MATH_SYMBOL},
                                                            {0x1D716, 0x1D71B, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D71C, 0x1D734, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D735, 0x1D735, UNICODE_MATH_SYMBOL},
                                                            {0x1D736, 0x1D74E, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D74F, 0x1D74F, UNICODE_MATH_SYMBOL},
                                                            {0x1D750, 0x1D755, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D756, 0x1D76E, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D76F, 0x1D76F, UNICODE_MATH_SYMBOL},
                                                            {0x1D770, 0x1D788, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D789, 0x1D789, UNICODE_MATH_SYMBOL},
                                                            {0x1D78A, 0x1D78F, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D790, 0x1D7A8, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D7A9, 0x1D7A9, UNICODE_MATH_SYMBOL},
                                                            {0x1D7AA, 0x1D7C2, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D7C3, 0x1D7C3, UNICODE_MATH_SYMBOL},
                                                            {0x1D7C4, 0x1D7C9, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D7CA, 0x1D7CA, UNICODE_UPPERCASE_LETTER},
                                                            {0x1D7CB, 0x1D7CB, UNICODE_LOWERCASE_LETTER},
                                                            {0x1D7CE, 0x1D7FF, UNICODE_DECIMAL_NUMBER},
                                                            {0x20000, 0x2A6D6, UNICODE_OTHER_LETTER},
                                                            {0x2F800, 0x2FA1D, UNICODE_OTHER_LETTER},
                                                            {0xE0001, 0xE0001, UNICODE_FORMAT},
                                                            {0xE0020, 0xE007F, UNICODE_FORMAT},
                                                            {0xE0100, 0xE01EF, UNICODE_NON_SPACING_MARK},
                                                            {0xF0000, 0xFFFFD, UNICODE_PRIVATE_USE},
                                                            {0x100000, 0x10FFFD, UNICODE_PRIVATE_USE},
                                                            {0x0, 0x0, UNICODE_INVALID}};
